@@ -4,11 +4,11 @@
 #                               Getleft
 ###############################################################################
 ###############################################################################
-# copyright (C) 1999-2002 Andres Garcia Garcia - fandom@retemail.es
+# copyright (C) 1999-2003 Andres Garcia Garcia - fandom@retemail.es
 # Distributed under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
-# Version 1.0.5
+# Version 1.1
 ###############################################################################
 ###############################################################################
 # This program recursively downloads Web sites, as it goes, it changes absolute
@@ -32,7 +32,7 @@ exec $wish "$0" ${1+"$@"}
 
 ###############################################################################
 # CheckPrograms
-#    Checks whether the programs Getleft relies on are within reach.
+#    Some checks to know if Getleft will be able to run.
 #
 # Side effects:
 #    If one of the programs is not in the path, the procedure will exit the
@@ -46,12 +46,7 @@ proc CheckPrograms {} {
                 Tcl/Tk v 8.1 or newer, yours is:\n\t $tcl_version" -title Error
         exit
     }
-    catch {exec curl}
-    if {[lindex $errorCode 1]=="ENOENT"} {
-        tk_messageBox -type ok -icon error -title "No curl" \
-            -message "Getleft depends on program\n\tcURL\nPlease check the docs"
-        exit
-    }
+
     if {$tcl_platform(platform)=="windows"} {
         if {[catch {load winkill.dll} result]} {
             tk_messageBox -type ok -icon error -title Error \
@@ -62,6 +57,47 @@ proc CheckPrograms {} {
     return
 }
 
+###############################################################################
+# UninstallGetleft
+#    When we run Getleft with the 'uninstall' command line option, we ask
+#    the user if he wants to delete his log files before uninstalling. 
+#
+#    This is bit of a kludge to be run from the [UninstallRun] section of
+#    Inno Setup.
+###############################################################################
+proc UninstallGetleft {} {
+    global tcl_platform dirGetleft argc argv global env
+
+    if {$tcl_platform(platform)!="windows"} {
+        return
+    }
+    set option [lindex $argv 0]
+    if {$option!="uninstall"} {
+        exit
+    }
+
+    set what [tk_messageBox -title Confirm -type yesno -icon question     \
+            -message "Do you want to delete your log files?"]
+    if {$what=="no"} {
+        exit
+    }
+    if {[info exists env(USERPROFILE)]} {
+        if {[catch {file delete -force $dirGetleft(conf)} error]} {
+            tk_messageBox -type ok -message $error -title Error -icon error
+        }
+        exit
+    }
+    catch {file delete -force      [file join $dirGetleft(conf) getleft.ini]}
+    catch {file delete -force      [file join $dirGetleft(conf) getLog.log]}
+    catch {file delete -force      [file join $dirGetleft(conf) fileDown.log]}
+    catch {file delete -force      [file join $dirGetleft(conf) cookies.txt]}
+    set gdtFiles [glob -nocomplain [file join $dirGetleft(conf) *.gdt]]
+    foreach gdt $gdtFiles {
+        catch {file delete -force $gdt}
+    }
+    exit
+}
+
 ###############################################################################
 # SetGetleftColours
 #     This is one of my world famous kludges, I use it in order to know
@@ -75,7 +111,13 @@ proc SetGetleftColours {} {
     set getleftOptions(bg)    [$tmp cget -background]
     set getleftOptions(fg)    [$tmp cget -foreground]
     set getleftOptions(selBg) [$tmp cget -selectbackground]
-    set getleftOptions(selFg) [$tmp cget -selectforeground] 
+    set getleftOptions(selFg) [$tmp cget -selectforeground]
+    # Tk default colour for the background of text widgets isn't white
+    # even though it should be.
+    if {($getleftOptions(bg)=="#dcdcdc")||($getleftOptions(bg)=="#d9d9d9") \
+            ||($getleftOptions(bg)=="#eae9e8")} {
+        set getleftOptions(bg) white
+    }
     destroy .tmp
 
     set tmp [frame .tmp]
@@ -83,9 +125,6 @@ proc SetGetleftColours {} {
     destroy .tmp
 
     button  .tmp
-    if {($getleftOptions(bg)=="#dcdcdc")||($getleftOptions(bg)=="#d9d9d9")} {
-        set getleftOptions(bg) white
-    }
     .tmp configure -state disable
     set getleftOptions(disFg) [.tmp cget -disabledforeground]
     destroy .tmp
@@ -108,20 +147,22 @@ proc SetGetleftColours {} {
 ###############################################################################
 proc InitializeDownload {url} {
     global directories siteUrl getleftState getleftOptions
-    global labelTitles labelMessages
+    global labelTitles labelMessages labelCurlCodes
 
     set getleftOptions(stopPage)          0
     set getleftOptions(stopFile)          0
-    set getleftOptions(pauseFile)         0
     set getleftOptions(cancelDown)        0
     set getleftState(errorFound)          0
+    set getleftOptions(pauseFile)         0
     set getleftOptions(pausePage)         0
+    set getleftOptions(pauseNow)          0
     set Ventana::Rizo::curlReport(stop)   0
 
     catch "unset ::filesDone"
     catch "unset ::Descargar::filesNotFound"
+    catch "unset ::Descargar::filesRelocated"
     catch "unset ::Descargar::relocated"
-    catch "unset ::Descargar::updated"
+    catch "unset ::Descargar::downloaded"
     catch "unset ::Commands::sedChanges"
 
     if {![regexp -nocase {([^:/])(/)} $url]} {
@@ -154,21 +195,24 @@ proc InitializeDownload {url} {
     }
 
     set directories(local)  $directories(base)
-    set siteUrl(base)       $siteUrl(dir)
+    set siteUrl(base)       [Commands::DeRexString $siteUrl(dir)]
 
     set result [Descargar::Download $url "-" $isHtml]
-
     if {$result==2} {
-        if {($Ventana::Rizo::errorMessage!="")&&($getleftState(autoDown)==0)} {
-            tk_messageBox -icon error -type ok -title $labelTitles(error) \
-                     -message "$Ventana::Rizo::errorMessage"
+        if {($Ventana::Rizo::curlError!=0)&&($Ventana::Rizo::curlError!="")} {
+            if {$getleftState(autoDown)==0} {
+                catch {wm withdraw $::Ventana::window(top)}
+                tk_messageBox -icon error -type ok -title $labelTitles(error) \
+                         -message "$labelCurlCodes($Ventana::Rizo::curlError)"
+            }
+            set getleftOptions(stopFile) 1
         }
-        return
+        return $url
     }
 
     if {($result==1)&&($isHtml==0)} {
-        set localFileName [::Commands::UrlToFile $url]
-        if {(![regexp {\.html?$} $localFileName])&&(![file exists $localFileName.html])} {
+        set localFileName [::Commands::UrlToFile $url $directories(base)]
+        if {(![regexp -nocase {\.html?$} $localFileName])&&(![file exists $localFileName.html])} {
             file rename -force $localFileName $localFileName.html
             Commands::Touch $localFileName
         }
@@ -181,12 +225,11 @@ proc InitializeDownload {url} {
             return
         }
         set fileName      [lindex $parsedUrl 3]
-
-        set siteUrl(base) $siteUrl(dir)
+        set siteUrl(base) [Commands::DeRexString $siteUrl(dir)]
         set url $Descargar::relocated(url)
         if {$result==4} {
-            set localFileName [::Commands::UrlToFile $url]
-            if {(![regexp {\.html?$} $localFileName])&&(![file exists $localFileName.html])} {
+            set localFileName [::Commands::UrlToFile $url $directories(base)]
+            if {(![regexp -nocase {\.html?$} $localFileName])&&(![file exists $localFileName.html])} {
                 file rename -force $localFileName $localFileName.html
                 Commands::Touch $localFileName
             }
@@ -213,9 +256,6 @@ proc TheEnd {{noEnd 0}} {
     if {($getleftOptions(stopFile)==1)||($getleftOptions(stopPage)==1)} {
         if {($getleftState(autoDown)==1)||($getleftState(delayedDown)==1)} {
             set what yes
-            if {$getleftState(autoDown)==1} {
-                mainWin::UrlListMoveTopBottom $getleftState(url)
-            }
             if {$getleftState(delayedDown)==1} {
                 catch {wm withdraw $::Ventana::window(top)}
             }
@@ -236,7 +276,7 @@ proc TheEnd {{noEnd 0}} {
             }
         }
     } else {
-        if {$getleftState(autoDown)==0} {
+        if {($getleftState(autoDown)==0)} {
             catch {wm withdraw $::Ventana::window(top)}
         }
         if {$noEnd==0} {
@@ -260,14 +300,6 @@ proc TheEnd {{noEnd 0}} {
     if {$::getleftState(exiting)==1} {
         exit
     }
-    if {$getleftState(autoDown)==1} {
-        if {[llength $getleftState(urlQueue)]>0} {
-            mainWin::NextToAutoDownload
-        } else {
-            catch {wm withdraw $::Ventana::window(top)}
-            mainWin::SetAutoDownload
-        }
-    }
     if {$getleftState(delayedDown)==1} {
         set getleftState(delayedDown) 0
         if {$Delay::delayedDownload(days)==0} {
@@ -387,10 +419,10 @@ proc StartDownload {requestedUrl} {
         TheEnd 1
         return
     }
-    set localFileName [::Commands::UrlToFile $requestedUrl]
+    set localFileName [::Commands::UrlToFile $requestedUrl $directories(base)]
     if {($getleftOptions(stopFile)==1)||($downOptions(levels)==0)\
             ||(![regexp -nocase {\.html?$} $localFileName])} {
-        TheEnd
+        TheEnd $getleftState(autoDown)
         return
     }
 
@@ -433,10 +465,10 @@ proc StartDownload {requestedUrl} {
                 set getleftState(mapDone) 0
             }
         }
-        #set ::start [clock seconds]
+#        set ::start [clock seconds]
         Descargar::ControlDownloading $requestedUrl 1
-        #set ::fin   [clock seconds]
-        #puts "Time: [expr $::fin - $::start]"
+#        set ::fin   [clock seconds]
+#        puts "Time: [expr $::fin - $::start]"
         if {$downOptions(map)==0} {
             TheEnd $getleftState(autoDown)
         } else {
@@ -467,6 +499,7 @@ proc StartDownload {requestedUrl} {
 ###############################################################################
 proc DownloadFromMap {requestedUrl} {
     global siteIndex siteMap getleftOptions downOptions getleftState
+    global directories
 
     set downOptions(onlyHtml)  0
     set tmpLevels              $downOptions(levels)
@@ -491,7 +524,7 @@ proc DownloadFromMap {requestedUrl} {
     for {set i 1} {$i<$siteIndex} {incr i} {
         if {$siteMap($i,ok)==1} {
             set enlace $siteMap($i,url)
-            set filename [::Commands::UrlToFile $enlace]
+            set filename [::Commands::UrlToFile $enlace $directories(base)]
             if {[file exists $filename]} {
                 continue
             } else {
@@ -550,12 +583,10 @@ proc SaveDownloadData {url} {
                 puts $file "set urlsDownloaded($url) $level"
             }
         }
-        if {$downOptions(update)==1} {
-            puts $file "\n\n# Urls that have been already updated\n\n"
-            foreach {url nada} [array get Descargar::updated] {
-                regsub {\$} $url {\\$} url
-                puts $file "set \"Descargar::updated($url)\" 1"
-            }
+        puts $file "\n\n# Urls that have been already downloaded\n\n"
+        foreach {url nada} [array get Descargar::downloaded] {
+            regsub {\$} $url {\\$} url
+            puts $file "set \"Descargar::downloaded($url)\" 1"
         }
     }
     puts $file "\n\n"
@@ -628,27 +659,27 @@ proc ReadConfig { {confFile {} } } {
                 set urlIndex $line
             }
             ^proxy$ {
-                set getleftOptions(httpProxy) $line
-                set getleftOptions(ftpProxy)  $line
-                set getleftOptions(sameProxy) 1
-                set getleftOptions(proxy)     1
+                set getleftOptions(httpProxy)    $line
+                set getleftOptions(ftpProxy)     $line
+                set getleftOptions(sameProxy)    1
+                set getleftOptions(proxy)        1
             }
             httpProxy {
-                set getleftOptions(httpProxy) $line
-                set getleftOptions(proxy)     1
+                set getleftOptions(httpProxy)    $line
+                set getleftOptions(proxy)        1
             }
             ftpProxy {
-                set getleftOptions(ftpProxy)  $line
-                set getleftOptions(proxy)     1
+                set getleftOptions(ftpProxy)     $line
+                set getleftOptions(proxy)        1
             }
             sameProxy {
-                set getleftOptions(sameProxy) $line
+                set getleftOptions(sameProxy)    $line
             }
             proxyUser {
-                set getleftOptions(proxyUser) $line
+                set getleftOptions(proxyUser)    $line
             }
             proxyPass {
-                set getleftOptions(proxyPass) $line
+                set getleftOptions(proxyPass)    $line
             }
             useAuthProxy {
                 set getleftOptions(useAuthProxy) $line
@@ -657,44 +688,49 @@ proc ReadConfig { {confFile {} } } {
                 set getleftOptions(saveAuthPass) $line
             }
             ^language$ {
-                set getleftOptions(lang) $line
+                set getleftOptions(lang)         $line
             }
             scripts {
-                set dirGetleft(scripts) $line
+                set dirGetleft(scripts)          $line
             }
             images {
-                set dirGetleft(images) $line
+                set dirGetleft(images)           $line
             }
             doc {
-                set dirGetleft(doc) $line
+                set dirGetleft(doc)              $line
             }
             languages {
-                set dirGetleft(languages) $line
+                set dirGetleft(languages)        $line
             }
             lastDir {
-                set dirGetleft(lastDir) $line
+                set dirGetleft(lastDir)          $line
             }
             toolDir {
-                set dirGetleft(toolDir) $line
+                set dirGetleft(toolDir)          $line
             }
             urlQueue {
-                lappend getleftState(urlQueue) $line
+                lappend getleftState(urlQueue)   $line
             }
             urlsToDownload {
                 eval "$line"
             }
             delaySet {
-                set getleftState(delaySet) $line
+                set getleftState(delaySet)       $line
             }
             delayData {
                 eval "$line"
             }
             defaultOptions {
-                array set defaultDownOptions $line
+                array set defaultDownOptions     $line
+            }
+            browser {
+                set getleftState(browser)        $line
+            }
+            icons   {
+                set dirGetleft(icons)            $line
             }
         }
     }
-
     close $handle
     if {[info exists update]} {
         file delete $ficherorc
@@ -710,6 +746,15 @@ proc ReadConfig { {confFile {} } } {
     if {![info exists urlIndex]} {
         set urlIndex 0
     }
+
+    # Just in case the user uninstalls a wrapped version and installs a
+    # normal one or viceversa
+    if {[info exists dirGetleft(icons)]} {
+        if {![file exists $dirGetleft(icons)]} {
+            set tmpDir [file tail $dirGetleft(icons)]
+            set dirGetleft(icons) [file join [GetMainDirectory] images $tmpDir]
+        }
+    }
     if {$getleftState(delaySet)==1} {
         Delay::DelayedSetStartTime
     }
@@ -732,7 +777,6 @@ proc SaveConfig {} {
 
     if {$tcl_platform(platform)=="windows"} {
         set ficherorc [file join "$dirGetleft(conf)" getleft.ini]
-
         # I got a bug report that said that Win2K doesn't like to
         # open hidden files, so I unhide it before opening
         if {[file exists $ficherorc]} {
@@ -795,6 +839,14 @@ proc SaveConfig {} {
     puts $fichero "\n\[defaultOptions\]\n"
     puts $fichero [array get defaultDownOptions]
 
+    puts $fichero "\n\[icons\]\n"
+    puts $fichero "$dirGetleft(icons)"
+
+    if {[info exists getleftState(browser)]} {
+        puts $fichero "\n\[browser\]\n"
+        puts $fichero "$getleftState(browser)"
+    }
+
     if {$getleftState(delaySet)==1} {
         puts $fichero "\n\[delayData\]\n"
         puts $fichero "array set Delay::delayedDownload \
@@ -808,10 +860,11 @@ proc SaveConfig {} {
         }
         puts $fichero "\n\[urlsToDownload\]\n"
         foreach site $getleftState(urlQueue) {
-            puts $fichero "set urlsToDownload($site)         1"
-            puts $fichero "set urlsToDownload($site,dir)     \"$urlsToDownload($site,dir)\""
-            puts $fichero "set urlsToDownload($site,resume)  $urlsToDownload($site,resume)"
-            puts $fichero "set urlsToDownload($site,options) [list $urlsToDownload($site,options)]"
+            regsub -all {\s} $site {\\&} siteTmp
+            puts $fichero "set urlsToDownload($siteTmp)         1"
+            puts $fichero "set urlsToDownload($siteTmp,dir)     \"$urlsToDownload($site,dir)\""
+            puts $fichero "set urlsToDownload($siteTmp,resume)  $urlsToDownload($site,resume)"
+            puts $fichero "set urlsToDownload($siteTmp,options) [list $urlsToDownload($site,options)]"
         }
     }
     close $fichero
@@ -861,7 +914,7 @@ proc PutUrlInHistory {url} {
 
 ###############################################################################
 # MostrarHistorial
-#    Shows the url history
+#    Shows the url history, only good for debuggin.
 ###############################################################################
 proc MostrarHistorial {} {
     global urlHistory urlIndex
@@ -925,6 +978,30 @@ proc ChangeLanguage {lang} {
     return
 }
 
+###############################################################################
+# ChangeIconSet
+#    Changes the default icon set for the program
+###############################################################################
+proc ChangeIconSet {} {
+    global dirGetleft getleftState
+
+    wm withdraw .
+
+    mainWin::MainWindow
+
+    if {$getleftState(downloading)==0} {
+        catch {destroy $::Ventana::window(top)}
+    }
+    catch {destroy $::getLog::siteLog(toplevel)}
+    catch {destroy $::getLog::fileLog(win)}
+
+    wm deiconify .
+
+    SaveConfig
+
+    return
+}
+
 ###############################################################################
 # ReadSupportedLang
 #    Reads the 'supported' file to know which languages this version supports
@@ -974,7 +1051,8 @@ proc ReadSupportedLang {} {
 proc ReadLangFile {sufix} {
     global dirGetleft supportedLang
     global labelMenus labelButtons  labelTitles labelMessages
-    global labelDialogs labelMonths labelFrames indexMenus
+    global labelDialogs labelMonths labelFrames 
+    global indexDialogs indexMenus indexButtons
     global labelCurlCodes confWizardLabels
 
     msgcat::mclocale $sufix
@@ -1001,35 +1079,39 @@ proc ReadLangFile {sufix} {
         set key   [lindex $line 0]
         set value [lindex $line 1]
 
+        set index [string first & $value]
+        if {$index!=-1} {
+            regsub {&} $value {} value
+        }
+
         switch -exact -- $active {
             Menus {
-                set indexMenus($key) [string first & $value]
-                if {$indexMenus($key)!=-1} {
-                    regsub {&} $value {} value
-                }
-                set labelMenus($key) $value
+                set indexMenus($key)       $index
+                set labelMenus($key)       $value
             }
             Buttons {
-                set labelButtons($key) $value
+                set indexButtons($key)     $index
+                set labelButtons($key)     $value
             }
             Titles {
-                set labelTitles($key) $value
+                set labelTitles($key)      $value
             }
             Messages {
-                set labelMessages($key) $value
+                set labelMessages($key)    $value
             }
             Dialogs {
-                set labelDialogs($key) $value
+                set labelDialogs($key)     $value
+                set indexDialogs($key)     $index
             }
             Months {
-                set labelMonths($key)   $value
-                set labelMonths($value) $key
+                set labelMonths($key)      $value
+                set labelMonths($value)    $key
             }
             Frames {
-                set labelFrames($key) $value
+                set labelFrames($key)      $value
             }
             curlCodes {
-                set labelCurlCodes($key) $value
+                set labelCurlCodes($key)   $value
             }
             confWizard {
                 set confWizardLabels($key) $value
@@ -1357,7 +1439,7 @@ proc ExitGetleft {} {
 
     if {$getleftState(downloading)==1} {
         set getleftState(exiting) 1
-        if {[Ventana::CancelDownloading $Ventana::window(top)]==0} {
+        if {[Ventana::CancelDownloading .]==0} {
             return
         }
         TheEnd
@@ -1370,6 +1452,25 @@ proc ExitGetleft {} {
     return
 }
 
+###############################################################################
+# GetMainDirectory
+#    This procedure investigates where the 'Getleft.tcl' or 'Getleft.exe' file
+#    are.
+#
+# Returns:
+#    The directory.
+###############################################################################
+proc GetMainDirectory {} {
+
+    set scriptDir [info script]
+    if {[file pathtype $scriptDir]=="relative"} {
+        set scriptDir [string trimleft $scriptDir ./]
+        set scriptDir [file join [pwd] $scriptDir]
+    }
+
+    return [file dirname $scriptDir]
+}
+
 ###############################################################################
 #                                PROGRAMA PRINCIPAL
 ###############################################################################
@@ -1380,11 +1481,9 @@ package require Tk
 
 wm withdraw .
 
-CheckPrograms
-
 package require msgcat
 
-set dirGetleft(main) [file dirname [info script]]
+set dirGetleft(main) [GetMainDirectory]
 
 if {$tcl_platform(platform)=="windows"} {
     if {[info exists env(USERPROFILE)]} {
@@ -1397,7 +1496,7 @@ if {$tcl_platform(platform)=="windows"} {
             }
         }
         # Since using the USERPROFILE folder is a new thing
-        # we will have to help the users who have their data
+        # we will have to help users who have their data
         # in other places
         if {[file exists [file join $dirGetleft(main) getleft.ini]]} {
             set fileList [list getlefti.ini cookies.txt Geterror.log getLog.log]
@@ -1427,7 +1526,7 @@ if {![file exists $dirGetleft(conf)]} {
     }
 }
 
-if {[file exists /etc/getlet.conf]} {
+if {[file exists /etc/getleft.conf]} {
     ReadConfig /etc/getleft.conf
 } elseif {[file exists /usr/local/etc/getleft.conf]} {
     ReadConfig /usr/local/etc/getleft.conf
@@ -1438,12 +1537,34 @@ if {[file exists /etc/getlet.conf]} {
     set dirGetleft(languages) [file join "$dirGetleft(main)" Languages]
 }
 
+if {$argc!=0} {
+    UninstallGetleft
+}
+
+ReadSupportedLang
+ReadLangFile en
+SetEncodings
+SetGetleftColours
+
+# We set a temp dirGetleft(icons) so we can source Ayuda.tcl
+if {![info exists dirGetleft(icons)]} {
+    set dirGetleft(icons) $dirGetleft(images)/Crystal
+}
+source [file join "$dirGetleft(scripts)" Ayuda.tcl]
+source [file join "$dirGetleft(scripts)" UnderButton.tcl]
+source [file join "$dirGetleft(scripts)" FrameLabel.tcl]
+source [file join "$dirGetleft(scripts)" Herramientas.tcl]
+source [file join "$dirGetleft(scripts)" delay.tcl]
+
+if {[ReadConfig]} {
+    source [file join "$dirGetleft(scripts)" getWizard.tcl]
+}
+
 source [file join "$dirGetleft(scripts)" mwutil.tcl]
 source [file join "$dirGetleft(scripts)" tablelistWidget.tcl]
 source [file join "$dirGetleft(scripts)" tablelistSortByColumn.tcl]
 source [file join "$dirGetleft(scripts)" balloon.tcl]
 source [file join "$dirGetleft(scripts)" mainWin.tcl]
-source [file join "$dirGetleft(scripts)" delay.tcl]
 source [file join "$dirGetleft(scripts)" Ventana.tcl]
 
 if {![info exists getleftState(downloading)]} {
@@ -1456,45 +1577,36 @@ if {![info exists getleftState(downloading)]} {
     set getleftState(waiting)                 0
     set getleftState(filesChosen)             0
     set ::Ventana::Rizo::curlReport(nextFile) 0
-    set setIcon 1
-}
-
-SetGetleftColours
-
-ReadSupportedLang
-ReadLangFile en
-SetEncodings
-
-source [file join "$dirGetleft(scripts)" FrameLabel.tcl]
-source [file join "$dirGetleft(scripts)" Herramientas.tcl]
-
-if {[ReadConfig]} {
-    source [file join "$dirGetleft(scripts)" getWizard.tcl]
 }
 
 mainWin::MainWindow
+wm deiconify .
+tkwait visibility .
 update
 
 source [file join "$dirGetleft(scripts)" menuEntry.tcl]
 source [file join "$dirGetleft(scripts)" Ccombinado.tcl]
 source [file join "$dirGetleft(scripts)" Dialogos.tcl]
-source [file join "$dirGetleft(scripts)" Ayuda.tcl]
-source [file join "$dirGetleft(scripts)" HtmlParser.tcl]
 source [file join "$dirGetleft(scripts)" Commands.tcl]
 source [file join "$dirGetleft(scripts)" Opciones.tcl]
 source [file join "$dirGetleft(scripts)" CuadroSpin.tcl]
 source [file join "$dirGetleft(scripts)" Descargar.tcl]
 source [file join "$dirGetleft(scripts)" Progreso.tcl]
 source [file join "$dirGetleft(scripts)" Cookies.tcl]
+source [file join "$dirGetleft(scripts)" HtmlParser.tcl]
 source [file join "$dirGetleft(scripts)" ChooseLinks.tcl]
 source [file join "$dirGetleft(scripts)" getLog.tcl]
 source [file join "$dirGetleft(scripts)" help.tcl]
 source [file join "$dirGetleft(scripts)" EnterUrl.tcl]
 
+CheckPrograms
+
 Ventana::Rizo::SetCurlVersion
 
 Opciones::SetDefaultOptions downOptions
 
+set getleftState(urlsToAutoDown) ""
+
 # We are going to delete the *.gdt files that shouldn't be there any more
 set gdtFiles [glob -nocomplain [file join $dirGetleft(conf) *.gdt]]
 foreach file $gdtFiles {
@@ -1504,17 +1616,5 @@ foreach file $gdtFiles {
     }
 }
 
-wm deiconify .
-
-tkwait visibility .
-
-if {$setIcon==1} {
-    if {$tcl_platform(platform)=="windows"} {
-        if {[regexp {((8\.3\.)(3|4))||(8.4)} $tcl_patchLevel]} {
-            catch {wm iconbitmap . -default [file join $dirGetleft(images) icon.ico]}
-        }
-    }
-    set setIcon 0
-}
-
+catch {focus -force .}
 
