@@ -3,7 +3,7 @@
 ###############################################################################
 ##### This file contains the Polish labels for the program
 ###############################################################################
-##### Copyright 1999-2002 Andrs Garca Garca. You may redistribute this file
+##### Copyright 1999-2003 Andrs Garca Garca. You may redistribute this file
 ##### under the terms of the GPL license. 
 ##### Wersja polska: "ooshy"  <ooshy@poczta.onet.pl>
 #####                Marek Dankowski <marek-sh@profit.pl>
@@ -14,7 +14,7 @@
 Menus
 
 file            "&Plik"
-enterUrl        "&Wpisz URL"
+enterUrl        "&Wpisz URL..."
 siteMap         "&Mapuj strony..."
 resumeSite      "W&znw"
 stop            "&Zatrzymaj"
@@ -51,11 +51,11 @@ encodings       "Kodowanie"
 tools           "&Narzdzia"
 purgeFiles      "&Cze plikw..."
 restoreOrig     "&Przywr oryginalne..."
-updateFiles     "Aktualizuj pliki..."
 configureProxy  "&Konfiguracja proxy..."
 languages       "&Jzyki"
 getLog          "Historia cigania"
-resource        "&rdo"
+#NOT TRANSLATED
+browser         "Choose &browser..."
 
 help            "Po&moc"
 manual          "&Instrukcja"
@@ -127,6 +127,8 @@ help            "Pomoc"
 load            "Load"
 save            "Save"
 
+launch          "See"
+
 back            "< Powrt"
 next            "Nastpny >"
 finish          "Koniec"
@@ -172,6 +174,10 @@ delayedDown     "Zadania oczekujce"
 timeout         "Limit czasu przekroczony"
 waiting         "Oczekiwanie"
 
+# NOT TRANSLATED
+sure            "Sure?"
+chooseBrow      "Choose browser"
+
 End
 
 # Labels for frames
@@ -189,7 +195,8 @@ authen         "Autentyfikacja"
 time           "Czas"
 stop           "Stop"
 days           "Dni"
-
+# NOT TRANSLATED
+browser        "Browser"
 End
 
 # Labels for message Boxes
@@ -216,7 +223,7 @@ noDate          "Serwer nie moe znowi  'Last-Modified' header\n      Continue?"
 intNaN          "Wewntrzny link limit\n   nie jest numerem."
 extNaN          "Zewntrzny link limit\n   nie jest numerem."
 follow          "Przej dalej?"
-noLinksOpt      "Nie ma liknkw w aktualnym ustawieniu"
+noLinksOpt      "Nie ma liknkw w aktualnym ustawieniu,\nplease the right-click menu to change them"
 emptyLog        "Plik bdw jest pusty"
 noUser          "Nie zosta wprowadzony uytkownik"
 noPass          "Nie zostao wprowadzone haso"
@@ -227,11 +234,18 @@ whichDays       "Wybierz dzie"
 timeoutCont     "Serwer nie odpowiada prawidowo\n\tKontynuowa?"
 # NOT TRANSLATED
 clearLog        "Do you want to clear the log?"
+fillBrowser     "Please, fill in the browser entry."
+cantBrowser     "Couldn't invoke browser"
+noBrowser       "I don't know how to invoke your browser."
+noWin           "This dialog is only for Unix."
+noFile          "The file doesn't exist"
 
 End
 
 # Various labels in dialog windows
-
+# Some of this labels can have an underscore in them to indicate
+# a shortcut in the application, please check the 'menus.en'
+# file to know which ones they are.
 Dialogs
 
 file            "Plik"
@@ -261,6 +275,10 @@ sameProxy       "Uyj taki sam adres proxy"
 http            "Http:"
 ftp             "Ftp:"
 copyLink        "Kopiuj link"
+# NOT TRANSLATED
+launchLink      "Launch link"
+launchRef       "Launch referrer"
+seeDown         "See download"
 url             "Adres"
 localDir        "Lokalny katalog"
 ready           "Gotw"
@@ -317,6 +335,8 @@ relocation    "Relokacja"
 code          "Code"
 size          "Size"
 
+other         "O&ther"
+
 # This is decimal separator as in PI==3.1415
 decimal       "."
 
@@ -394,6 +414,10 @@ lanSub     "Wybierz domylny jzyk."
 proxTitle  "Konfiguracja proxy proxy"
 proxSub    "Skonfiguruj proxy, jeli potrzebujesz."
 
+# NOT TRANSLATED
+browTitle  "Choose Browser"
+browSub    "Which browser would you like to use?"
+
 sureTitle  "Sprawd"
 sureMssg   "Opucic konfiguracj?"
 
