@@ -23,9 +23,9 @@ proc ReadConfig {confFile } {
 
 wm withdraw .
 wm overrideredirect . 1
-
-if {[file exists ../scripts/help.tcl]} {
-    set helpDir ../scripts/
+set scriptDir [file dirname [info script]]
+if {[file exists [file join $scriptDir ../scripts/help.tcl]]} {
+    set helpDir [file join [file dirname [info script]] ../scripts/]
 } else {
     if {$tcl_platform(platform)=="unix"} {
         if {[file exists /etc/getlet.conf]} {
@@ -39,10 +39,15 @@ if {[file exists ../scripts/help.tcl]} {
         }
     }
 }
-
+# We set a temp dirGetleft(icons) so we can source Ayuda.tcl
+if {![info exists dirGetleft(icons)]} {
+    set dirGetleft(images) [file join $helpDir .. images]
+    set dirGetleft(icons)  [file join $dirGetleft(images) Crystal]
+}
+source [file join $helpDir Ayuda.tcl]
 source [file join $helpDir help.tcl]
 
-help::init help.help
+help::init [file join $scriptDir help.help] contents "" 450 525
 
 after 1000 exit_on_destroy
 
