@@ -4,7 +4,7 @@
 #                               install
 ###############################################################################
 ###############################################################################
-# copyright (C) 2002 Andres Garcia Garcia - fandom@retemail.es
+# copyright (C) 2002-2003 Andres Garcia Garcia - fandom@retemail.es
 # Distributed under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -67,9 +67,9 @@ proc InstallDirs {} {
     set installDirs(lan) [file join $options(prefix) share getleft languages]
     set docRoot [file join $options(prefix) share doc]
     if {[file exists $docRoot]} {
-        set installDirs(doc) [file join $options(prefix) share doc getleft-1.0]
+        set installDirs(doc) [file join $options(prefix) share doc getleft-1.1]
     } else {
-        set installDirs(doc) [file join $options(prefix) doc getleft-1.0]
+        set installDirs(doc) [file join $options(prefix) doc getleft-1.1]
     }
     return
 }
@@ -101,6 +101,8 @@ proc WriteConfFile {} {
     puts $handle "$installDirs(lan)\n"
     puts $handle "\[images\]\n"
     puts $handle "$installDirs(img)\n"
+    puts $handle "\[icons\]\n"
+    puts $handle "$installDirs(img)/Crystal\n"
 
     if {$options(proxy)!=""} {
         puts $handle "\[proxy\]\n"
@@ -133,6 +135,9 @@ proc InstallFiles {} {
     if {![file exists $installDirs(img)]} {
         file mkdir $installDirs(img)
     }
+    foreach file [glob -nocomplain [file join $installDirs(img) *]] {
+        file delete -force $file
+    }
     foreach imgFile [glob images/*] {
         file copy -force $imgFile $installDirs(img)
     }
