@@ -14,6 +14,23 @@
 
 namespace eval ChooseLinks {
 
+image create bitmap mas -data "
+    #define mas_width 16
+    #define mas_height 16
+    static unsigned char mas_bits[] = {
+        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x80, 0x01,
+        0x80, 0x01, 0xf0, 0x0f, 0xf0, 0x0f, 0x80, 0x01, 0x80, 0x01, 0x80, 0x01,
+        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
+"
+image create bitmap menos -data "
+    #define menos_width 16
+    #define menos_height 16
+    static unsigned char menos_bits[] = {
+        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+        0x00, 0x00, 0xf0, 0x0f, 0xf0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
+"
+
 ###############################################################################
 # Traces
 #    When one of the options change this procedure is invoked to change the
@@ -77,16 +94,19 @@ proc CopyLink {textPath} {
 #
 # Parameter
 #    textPath: Path of the text widget where the links are.
+#    linkArray: The array with the links.
 ###############################################################################
-proc PutInQueue {textPath} {
+proc PutInQueue {textPath linkArray} {
     global dirGetleft
     variable win
 
+    upvar #0 $linkArray links
+
     regexp {(.*)(\.)} [$textPath index insert] nada line
-    for {set i 1;set j 0} {$i<$HtmlParser::nLinks} {incr i} {
-        incr j $HtmlParser::links($i,shown)
+    for {set i 1;set j 0} {[info exists links($i,url)]} {incr i} {
+        incr j $links($i,shown)
         if {$j==$line} {
-            set urlToDownload $HtmlParser::links($i,url)
+            set urlToDownload $links($i,url)
             break
         }
     }
@@ -158,6 +178,8 @@ proc ContextMenu {link x y} {
 proc Chosen {linkArray pattern select} {
     global siteMap downOptions
 
+    set pattern [subst $pattern]
+    if {$pattern=="(\$)"} return
     upvar #0 $linkArray links
 
     for {set i 1} {[info exists links($i,url)]} {incr i} {
@@ -213,7 +235,7 @@ proc ChooseGroup {which action} {
 #    linkArray: The name of the array where the links are stored.
 ###############################################################################
 proc ChangeLinksToChoose {linkArray} {
-    global filesDone
+    global filesDone directories
     variable win
     variable refererUrl
 
@@ -224,11 +246,10 @@ proc ChangeLinksToChoose {linkArray} {
 
     set file [lindex [array get filesDone] 0]
     catch {unset filesDone}
-    set refererFile [::Commands::UrlToFile $refererUrl]
+    set refererFile [::Commands::UrlToFile $refererUrl $directories(base)]
 
     HtmlParser::FilterLinks $refererUrl $linkArray
-#    Commands::ChangePage $refererUrl
-
+    Commands::ChangePage $refererUrl
     LinksToChoose $linkArray
 
     $win(text) configure -state  disabled
@@ -333,7 +354,7 @@ proc SetEncodingMenus {menu encodings referer linkArray} {
 #    linkArray: Array where the links to be shown are stored.
 ###############################################################################
 proc ChooseDownloads {referer linkArray} {
-    global labelButtons labelTitles labelDialogs labelMenus
+    global labelButtons labelTitles labelDialogs labelMenus indexButtons
     global dirGetleft downOptions charSets getleftState getleftOptions
     variable refererUrl $referer
     variable traces
@@ -357,36 +378,47 @@ proc ChooseDownloads {referer linkArray} {
             -cursor left_ptr -bg $getleftOptions(bg)]
     set win(text) $texto
 
-    set aceptar [button $botones.aceptar   -textvariable labelButtons(ok)     \
+    set aceptar [underButton::UnderButton $botones.aceptar -buttontype button \
+            -textvariable labelButtons(ok)     -under $indexButtons(ok)       \
             -width 9 -command "
                 mainWin::UpdateUrlOptions
                 ChooseLinks::SetChosenLinks
                 set ChooseLinks::done 1"]
-    set cancelar [button $botones.cancelar -textvariable labelButtons(cancel) \
+    set cancelar [underButton::UnderButton $botones.cancelar -buttontype button\
+            -textvariable labelButtons(cancel) -under $indexButtons(cancel)    \
             -width 9 -command "set ChooseLinks::done 0" ]
+    set launch   [underButton::UnderButton $botones.launch   -buttontype button\
+            -textvariable labelButtons(launch) -under $indexButtons(launch)    \
+            -width 9 -command "Ayuda::InvokeBrowser $referer $win(top)"]
 
-    set mas   [image create bitmap  -file [file join $dirGetleft(images) mas]]
-    set menos [image create bitmap  -file [file join $dirGetleft(images) menos]]
     set lhtml [label  $checks.lhtml -text "  $labelDialogs(html)"]
-    set htmla [button $checks.htmla -image $mas   -width 8 -height 8 \
+    set htmla [button $checks.htmla -image mas   -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {(html$)|(htm$)|(/$)} 1"]
-    set htmle [button $checks.htmle -image $menos -width 8 -height 8 \
+    set htmle [button $checks.htmle -image menos -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {(html$)|(htm$)|(/$)} 0"]
     set lima  [label $checks.lima   -text "  $labelDialogs(images)"]
-    set imaa  [button $checks.imaa  -image $mas   -width 8 -height 8 \
+    set imaa  [button $checks.imaa  -image mas   -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff?$)|(png$)} 1"]
-    set imae  [button $checks.imae  -image $menos -width 8 -height 8 \
+    set imae  [button $checks.imae  -image menos -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff?$)|(png$)} 0"]
     set lcom  [label $checks.lcom   -text "  $labelDialogs(archives)"]
-    set coma  [button $checks.cona  -image $mas   -width 8 -height 8 \
-            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)|(tgz$)|(rpm$)|(deb$)} 1"]
-    set come  [button $checks.cone  -image $menos -width 8 -height 8 \
-            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)|(tgz$)|(rpm$)|(deb$)} 0"]
+    set coma  [button $checks.cona  -image mas   -width 8 -height 8 \
+            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)|(tgz$)|(rpm$)|(deb$)|(sit$)} 1"]
+    set come  [button $checks.cone  -image menos -width 8 -height 8 \
+            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)|(tgz$)|(rpm$)|(deb$)|(sit$)} 0"]
     set ltodo [label $checks.ltodo  -text "  $labelDialogs(all)"]
-    set todoa [button $checks.todoa -image $mas   -width 8 -height 8 \
+    set todoa [button $checks.todoa -image mas   -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {.} 1"]
-    set todoe [button $checks.todoe -image $menos -width 8 -height 8 \
+    set todoe [button $checks.todoe -image menos -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {.} 0"]
+    set lany  [label $checks.lany   -text "  "]
+    set eany  [entry $checks.eany   -width 4 -bg $getleftOptions(bg) \
+            -fg $getleftOptions(fg) -textvariable ChooseLinks::anyExtension]
+    set ChooseLinks::anyExtension ""
+    set anya [button $checks.anya -image mas   -width 8 -height 8 \
+            -command "ChooseLinks::Chosen $linkArray {(\$ChooseLinks::anyExtension\$)} 1"]
+    set anye [button $checks.anye -image menos -width 8 -height 8 \
+            -command "ChooseLinks::Chosen $linkArray {(\$ChooseLinks::anyExtension\$)} 0"]
 
     LinksToChoose $linkArray
 
@@ -408,7 +440,7 @@ proc ChooseDownloads {referer linkArray} {
     $menu add command -label "$labelDialogs(copyLink)"   \
             -command "ChooseLinks::CopyLink $texto"
     $menu add command -label "$labelMenus(queue)"        \
-            -command "ChooseLinks::PutInQueue $texto"
+            -command "ChooseLinks::PutInQueue $texto $linkArray"
     $menu add separator
     $menu add cascade -label "$labelMenus(options)" -menu  $menu.options
 
@@ -497,6 +529,7 @@ proc ChooseDownloads {referer linkArray} {
             -label $labelMenus(images)
     $menuFil add command -label $labelMenus(chooseFilter) -command "
         Herramientas::FilterFiles \"$downOptions(filter)\" $win(top)
+
         ChooseLinks::ChangeLinksToChoose $linkArray
     "
 
@@ -583,14 +616,14 @@ proc ChooseDownloads {referer linkArray} {
     grid $barrax -sticky ew
     grid $checks -sticky ew
     grid $lhtml $htmla $htmle $lima $imaa $imae $lcom $coma $come \
-            $ltodo $todoa $todoe
+            $ltodo $todoa $todoe $lany $eany $anya $anye -pady 2
     grid $botones -sticky ew -ipady 4
-    grid $aceptar $cancelar  -padx 3
+    grid $launch $aceptar $cancelar  -padx 3
 
     grid rowconfigure    $win(top) 0 -weight 1
     grid columnconfigure $win(top) 0 -weight 1
-    grid rowconfigure    $marco  0 -weight 1
-    grid columnconfigure $marco  0 -weight 1
+    grid rowconfigure    $marco    0 -weight 1
+    grid columnconfigure $marco    0 -weight 1
 
     $texto configure -state disabled
 
