@@ -6,7 +6,7 @@
 ## Includes the procedures needed for downloading a link
 ###############################################################################
 ###############################################################################
-## (c) 2001-2002 Andrs Garca Garca. fandom@retemail.es
+## (c) 2001-2003 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -67,17 +67,26 @@ proc CheckDir {fileName} {
 ###############################################################################
 proc FileExists {link fileName sufix} {
     global downOptions
-    variable updated
     variable relocated
+    variable downloaded
 
     if {[file exists $fileName]} {
-        if {($downOptions(update)==0)||([info exists "updated($fileName)"])} {
+        if {($downOptions(update)==0)||[info exists "downloaded($link)"]} {
             if {$sufix==0} {
+                # It may so happen with CGI scripts that there is a directory
+                # and a file with the same name, I wish webmasters stopped 
+                # being clever about the names of CGI scripts, but there is
+                # nothing I can do to stop them being stupid.
                 if {([file isdirectory $fileName])&&(![regexp {/$} $fileName])} {
-        	        if {[file exists $fileName/index.html]} {
-            	        set relocated(url) $link/index.html
-                	   return 4
+                    if {[file exists $fileName/index.html]} {
+                        set relocated(url) $link/index.html
+                    } elseif {[file exists $fileName.html]} {
+                        set relocated(url) $link.html
+                    } else {
+                        set relocated(url) $link/index.html
+                        return -1
                     }
+                    return 4
                 } elseif {[file exists $fileName.html]} {
                     return 1
                 } else {
@@ -118,7 +127,7 @@ proc ConnectTimeout {link referer code} {
     }
     if {$getleftState(noConnect,$siteUrl(www))>10} {
         if {$getleftState(autoDown)!=1} {
-            set what [tk_messageBox  -title $labelCurlCode(code)          \
+            set what [tk_messageBox  -title $labelCurlCodes($code)          \
                       -type yesno    -message $labelMessages(timeoutCont) \
                       -icon question -parent $::Ventana::window(top)]
             if {$what=="yes"} {
@@ -151,9 +160,11 @@ proc ConnectTimeout {link referer code} {
 ###############################################################################
 proc RelocatedLink {link newLink referer} {
     global getleftState labelTitles labelMessages labelDialogs siteUrl
+    global directories
     variable relocated
     variable relocatedLink
     variable filesNotFound
+    variable filesRelocated
 
     set newLink [::HtmlParser::CompleteUrl $newLink $referer ""]
     set relocated(url) $newLink
@@ -164,7 +175,7 @@ proc RelocatedLink {link newLink referer} {
 
     if {($getleftState(filesChosen)==0)&&($getleftState(autoDown)==0)} {
         set what [tk_messageBox -title $labelTitles(relocation) -type yesno \
-                -icon question -parent $::Ventana::window(top) \
+                -icon question -parent $::Ventana::window(top)              \
                 -message "$labelMessages(follow)\n$newLink"]
         if {$what=="no"} {
             return 1
@@ -177,22 +188,29 @@ proc RelocatedLink {link newLink referer} {
     }
     set relocatedLink(1,url)  $newLink
     set relocatedLink(1,ok)   1
-    set relocatedLink(1,file) [::Commands::UrlToFile $newLink]
+    set relocatedLink(1,file) [::Commands::UrlToFile $newLink $directories(base)]
 
     ::HtmlParser::FilterLinks $referer Descargar::relocatedLink
 
+    set filesRelocated($link,url)  $newLink
+    set filesRelocated($link,ok)   $relocatedLink(1,ok)
+    set filesRelocated($link,file) $relocatedLink(1,file)
+    if {[regexp {\.html?} $relocatedLink(1,file)]} {
+        set filesRelocated($link,html) 1
+    } else {
+        set filesRelocated($link,html) 0
+    }
+
     if {$relocatedLink(1,ok)==1} {
-        ::getLog::FileLogEnter \
+        ::getLog::FileLogEnter                                              \
                 $labelDialogs(relocation) $link $referer
         ::getLog::FileLogEnter "" "$newLink" "$link"
         return 0
     }
-    ::getLog::FileLogEnter \
+    ::getLog::FileLogEnter                                                  \
             "$labelMessages(noFollow)" "$link" "$referer"
     ::getLog::FileLogEnter "" "$newLink" "$link"
 
-    set filesNotFound($link) 1
-
     return 1
 }
 
@@ -255,18 +273,12 @@ proc UpdateFile {fileName} {
 ###############################################################################
 proc DownloadHead {link referer sufix} {
     global Ventana::Rizo::meta
-    global siteUrl getleftState
+    global siteUrl getleftState  directories
     global errorCode labelTitles labelMessages
     variable filesNotFound
     variable relocated
 
     for {set relocated(ok) 0} {1==1} {} {
-        if {[regexp {^ftp://} $link]} {
-            set meta(content)       "nada"
-            set meta(totalBytes)    0
-            set meta(versionServer) 1.1
-            break
-        }
         for {} {1==1} {} {
             Ventana::HeadDownloading $link $referer
             if {($::Ventana::Rizo::curlError==7)||($::Ventana::Rizo::curlError==28)||($::Ventana::Rizo::curlError==52)} {
@@ -298,6 +310,7 @@ proc DownloadHead {link referer sufix} {
             }	    
         }
         if {$meta(relocate)!=""} {
+#            set filesNotFound($link) 1
             if {$::DEBUG==1} {
                 puts "Relocated: $meta(relocate)"
             }
@@ -310,7 +323,7 @@ proc DownloadHead {link referer sufix} {
             set newWWW    [lindex $parsedUrl 1]
             set newDir    [lindex $parsedUrl 2]
 
-            set fileName  [::Commands::UrlToFile $relocated(url)]
+            set fileName  [::Commands::UrlToFile $relocated(url) $directories(base)]
             set link      $relocated(url)
             set relocated(ok) 1
             if {[file exists $fileName]} {
@@ -327,7 +340,7 @@ proc DownloadHead {link referer sufix} {
         }
     }
 # Some servers don't return a mime time, that's why we also check the sufix
-    if {($meta(content)!="text/html")&&($sufix!=1)} { 
+    if {($meta(content)!="text/html")&&(![regexp {html?$} $link])} { 
         return 0
     }
     return 1
@@ -403,24 +416,28 @@ proc Download {link referer sufix} {
     global Ventana::Rizo::meta
     global directories
     global labelDialogs labelMessages
-    variable updated
+    variable downloaded
     variable filesNotFound
+    variable filesRelocated
     variable relocated
 
     if {[info exists filesNotFound($link)]} {
         return 2
     }
 
-    set fileName [::Commands::UrlToFile $link]
+    if {[info exists filesRelocated($link,url)]} {
+        set relocated(ok)  1
+        set relocated(url) $filesRelocated($link,url)
+        return [expr $filesRelocated($link,html)+3]
+    }
+
+    set fileName [::Commands::UrlToFile $link $directories(base)]
 
     set returnCode [FileExists $link $fileName $sufix]
-
     if {$returnCode!=-1} {
         return $returnCode
     } else {
-        if {$downOptions(update)==1} {
-            set updated($fileName) 1
-        }
+        set downloaded($fileName) 1
     }
 
     set returnCode [DownloadHead $link $referer $sufix]
@@ -433,7 +450,7 @@ proc Download {link referer sufix} {
     }
     if {$relocated(ok)==1} {
         set link $relocated(url)
-        set fileName [::Commands::UrlToFile $link]
+        set fileName [::Commands::UrlToFile $link $directories(base)]
 
     }
     if {($isHtml==0)&&($downOptions(onlyHtml)==1)} {
@@ -458,8 +475,14 @@ proc Download {link referer sufix} {
     }
     if {[DownloadFile $link $referer $fileName]} {
         return 2
-    }            
-    catch {file rename -force $fileName.$labelMessages(downSuffix) $fileName}
+    }
+    # With CGI links it may happen that a file and a directory have the same
+    # name.
+    if {[file isdirectory $fileName]} {
+        file rename -force $fileName.$labelMessages(downSuffix) $fileName.html
+    } else {
+        catch {file rename -force $fileName.$labelMessages(downSuffix) $fileName}
+    }
     if {$isHtml==1} {
         file delete $fileName.orig
     }
@@ -487,7 +510,7 @@ proc Download {link referer sufix} {
 #    The link list with only the Html links.
 ###############################################################################
 proc DownloadLinks {urlList referer} {
-    global downOptions getleftOptions
+    global downOptions getleftOptions directories
     variable relocated
 
     set invokeSed 0
@@ -496,17 +519,20 @@ proc DownloadLinks {urlList referer} {
     foreach urlToDownload $urlList {
         update
         if {$downOptions(onlyHtml)==1} {
-            if {[regexp -nocase -expanded {(jpg)|(jpeg)|(gif)|(gz)|(tar)|(zip)|     \
-                                           (exe)|(ps)|(pdf)|(txt)|(text)|(avi)|     \
-                                           (ram)|(wav)|(png)|(tif)|(mov)|(qt)|(js)} \
+            if {[regexp -nocase -expanded {(jpg)|(jpeg)|(gif)|(gz) |(tar) |(zip)|     \
+                                           (exe)|(ps)  |(pdf)|(txt)|(text)|(avi)|     \
+                                           (ram)|(wav) |(png)|(tif)|(mov) |(qt) |     \
+                                           (js) |(rpm)} \
                 [file extension $urlToDownload]]} {
                 continue
             }
         }
-        set fileName [Commands::UrlToFile $urlToDownload]
-
+        set fileName [Commands::UrlToFile $urlToDownload $directories(base)]
         set changedPageLink [Commands::RelativePath $referer $urlToDownload]
 
+        set tag ""
+        regexp {(#.*)} $urlToDownload tag
+
         if {[regexp {/$} $urlToDownload]} {
             lappend urlListTemp ${urlToDownload}index.html
         }
@@ -520,11 +546,11 @@ proc DownloadLinks {urlList referer} {
         switch -regexp -- $isHtml {
             1 {
                 if {$sufix==0} {
-                    catch {file rename $fileName $fileName.html}
+                    catch {file rename -force $fileName $fileName.html}
                     Commands::Touch $fileName
                     lappend urlListTemp $urlToDownload.html
-                    Commands::SedChangeEnter $changedPageLink  \
-                                             ${changedPageLink}.html
+                    Commands::SedChangeEnter $changedPageLink$tag          \
+                                             ${changedPageLink}.html$tag
                     set invokeSed 1
                 } else {
                     lappend urlListTemp $urlToDownload 
@@ -536,8 +562,8 @@ proc DownloadLinks {urlList referer} {
                 if {$isHtml==4} {
                     if {$sufix==0} {
                         lappend urlListTemp $relocated(url).html
-                        set localFileName [::Commands::UrlToFile $relocated(url)]
-                        if {(![regexp {\.html?$} $localFileName])&&(![file exists $localFileName.html])} {
+                        set localFileName [::Commands::UrlToFile $relocated(url) $directories(base)]
+                        if {(![regexp -nocase {\.html?$} $localFileName])&&(![file exists $localFileName.html])} {
                             file rename -force $localFileName $localFileName.html
                             Commands::Touch $localFileName
                         }
@@ -546,7 +572,7 @@ proc DownloadLinks {urlList referer} {
                         lappend urlListTemp $relocated(url)
                     }
                 }
-                Commands::SedChangeEnter $changedPageLink $newLink
+                Commands::SedChangeEnter $changedPageLink$tag $newLink$tag
                 set invokeSed 1
             }
         }
@@ -558,7 +584,7 @@ proc DownloadLinks {urlList referer} {
         }
     }
     if {$invokeSed==1} {
-        Commands::Sed [::Commands::UrlToFile $referer]
+        Commands::Sed [::Commands::UrlToFile $referer $directories(base)]
     }
     return $urlListTemp
 }
@@ -576,10 +602,9 @@ proc Preprocessing {url level} {
     global directories getleftState charSets filesDone
 
     if {[string match $url ""]} return
-
-    set file [::Commands::UrlToFile $url]
+    set file [::Commands::UrlToFile $url $directories(base)]
     set filesDone($file) $level
-    if {![regexp {\.html?$} $file]} return
+    if {![regexp -nocase {\.html?$} $file]} return
 
 #    if {$::DEBUG==1} {
 #        puts "Fichero a preprocesar: $file"
@@ -643,7 +668,7 @@ proc ProcessUrlList {urlList level {externalLevel 0}} {
     global filesDone getleftState
 
     foreach url $urlList {
-        set fileToProcess   [::Commands::UrlToFile $url]
+        set fileToProcess   [::Commands::UrlToFile $url $directories(base)]
         set parsedUrl       [HtmlParser::ParseUrl $url]
         if {[info exists filesDone($fileToProcess)]} {
             if {($level>=$filesDone($fileToProcess))||($downOptions(levels)==-1)\
@@ -705,11 +730,11 @@ proc PrepareDownloading {currentLevel} {
             lappend urlList $HtmlParser::links($i,url)
         }
         if {$downOptions(map)==1} {
-            set siteMap($siteIndex,level)   $currentLevel
-            set siteMap($siteIndex,url)     $HtmlParser::links($i,url)
-            set siteMap($siteIndex,file)    $HtmlParser::links($i,file)
-            set siteMap($siteIndex,descrip) $HtmlParser::links($i,descrip)
-            catch "set siteMap($siteIndex,type) $HtmlParser::links($i,type)"
+            set siteMap($siteIndex,level)       $currentLevel
+            set siteMap($siteIndex,url)         $HtmlParser::links($i,url)
+            set siteMap($siteIndex,file)        $HtmlParser::links($i,file)
+            set siteMap($siteIndex,descrip)     $HtmlParser::links($i,descrip)
+            catch {set siteMap($siteIndex,type) $HtmlParser::links($i,type)}
             set siteMap($HtmlParser::links($i,url)) 1
             incr siteIndex
         }
