@@ -8,24 +8,15 @@
 ##### knowing very well what I was doing, so please, don't blame him for all
 ##### the weirdness.
 ###############################################################################
-##### Copyright 1999-2002 Brent Welch - Andrs Garca.  fandom@retemail.es
-##### The contents of this file are distributed under the terms of the GPL
+##### Copyright 1999-2003 Brent Welch - Andrs Garca.  fandom@retemail.es
+##### The contents of this file are distributed under the terms of the LGPL
 ###############################################################################
 
 namespace eval Dialogos {
 
-set useWinDialog 0
-if {$tcl_platform(platform)=="windows"} {
-    if {[regexp {(8\.4b2)|(8.4$)|(8.4.0)} $tcl_patchLevel]} {
-        set useWinDialog 1
-    } else {
-        set useWinDialog 0
-    }
-}
-
 ###############################################################################
 # SelectDirWindows
-#     Does the work by using a window dialog
+#     Does the work by using a Windows dialog
 #
 # Parameters:
 #     initialDir: The directory in which the dialog will open itself.
@@ -38,7 +29,7 @@ if {$tcl_platform(platform)=="windows"} {
 #     If you select a non-existing directory, it will be created for you.
 ###############################################################################
 proc SelectDirWindows {initialDir parent} {
-    global labelTitles labelMessages
+    global labelTitles labelMessages indexButtons
 
     set chosenDir [tk_chooseDirectory -title $labelTitles(directory)         \
             -parent $parent -initialdir $initialDir]
@@ -77,10 +68,18 @@ proc SelectDirWindows {initialDir parent} {
 proc SelectDirectory {{initialDir {} } {parent {.} } } {
     variable fileselect
     variable useWinDialog
-    global tcl_platform
-    global dirGetleft getleftOptions labelMenus
+    global tcl_platform tcl_patchLevel
+    global dirGetleft getleftOptions labelMenus indexButtons
     global env labelButtons labelTitles labelDialogs labelMessages
 
+    if {![info exists useWinDialog]} {
+        set useWinDialog 0
+        if {$tcl_platform(platform)=="windows"} {
+            if {[regexp {(8\.4b2)|(8.4$)|(8.4.[0-9]+)} $tcl_patchLevel]} {
+                set useWinDialog 1
+            }
+        }
+    }
     if {$useWinDialog==1} {
         return [SelectDirWindows $initialDir $parent]
     }
@@ -97,9 +96,9 @@ proc SelectDirectory {{initialDir {} } {parent {.} } } {
 
     set fdir [frame $t.directorio]
     set imaArr [image create photo \
-            -file [file join "$dirGetleft(images)" arriba.gif]]
+            -file [file join "$dirGetleft(icons)" arriba.gif]]
     set imaNew [image create photo \
-            -file [file join "$dirGetleft(images)"  nuevo.gif]]
+            -file [file join "$dirGetleft(icons)" nuevo.gif]]
     button $fdir.arriba -image $imaArr -command {
         Dialogos::fileselectList [file dirname $Dialogos::fileselect(dir)]
         Dialogos::fileselectOK
@@ -131,8 +130,8 @@ proc SelectDirectory {{initialDir {} } {parent {.} } } {
     # el valor se guarda en fileselect(path)
     frame $t.top
     label $t.top.l -text "$labelDialogs(dir): " -padx 0
-    set e [menuEntry::menuEntry $t.top.path -relief sunken -bg $getleftOptions(bg) \
-           -fg $getleftOptions(fg) -width 27                        \
+    set e [menuEntry::menuEntry $t.top.path -relief sunken           \
+           -fg $getleftOptions(fg) -width 27 -bg $getleftOptions(bg) \
            -textvariable Dialogos::fileselect(path)]
     pack $t.top -side top -fill x
     pack $t.top.l -side left
@@ -150,17 +149,19 @@ proc SelectDirectory {{initialDir {} } {parent {.} } } {
 
     #Botones de Abrir y cancelar
 
-    button $t.top.ok -textvariable labelButtons(select) -width 10 -height 1 \
+    underButton::UnderButton $t.top.ok -buttontype button -width 10           \
+            -textvariable labelButtons(select) -under $indexButtons(select)   \
             -command {
-        if {[Dialogos::fileselectOK]==1} {
-            set Dialogos::fileselect(done) 1
-        }
+                if {[Dialogos::fileselectOK]==1} {
+                set Dialogos::fileselect(done) 1
+            }
     }
     pack $t.top.ok -side right
 
     frame $t.cancel
-    button $t.cancel.cancelar -textvariable labelButtons(cancel) \
-            -command {set Dialogos::fileselect(done) 0} -width 10
+    underButton::UnderButton $t.cancel.cancelar -buttontype button -width 10  \
+            -textvariable labelButtons(cancel)  -under $indexButtons(cancel)  \
+            -command {set Dialogos::fileselect(done) 0}
     pack $t.cancel.cancelar -side right
     pack $t.cancel -side bottom -fill x
     wm protocol $t WM_DELETE_WINDOW "$t.cancel.cancelar invoke"
@@ -200,7 +201,10 @@ proc SelectDirectory {{initialDir {} } {parent {.} } } {
     tkwait visibility .fileselect.lista.list
     fileselectList $dir
 
+    grab .fileselect
     tkwait variable Dialogos::fileselect(done)
+    grab release .fileselect
+
     destroy .fileselect
     update     
     if {$fileselect(done)==1} {
@@ -252,7 +256,7 @@ proc NewDir {} {
     bind $dialog <Escape> "$cancelar invoke"
 
     focus $dirEnt
-#    grab $dialog
+    grab $dialog
     tkwait variable Dialogos::done
 
     if {$done==1} {
@@ -266,7 +270,7 @@ proc NewDir {} {
             }
         }
     }
-#    grab release $dialog
+    grab release $dialog
     destroy $dialog
     return
 }
