@@ -6,7 +6,7 @@
 ## Takes care of the dialog that prompts the user for an Url to download.
 ###############################################################################
 ###############################################################################
-## (c) 2002 Andrs Garca Garca. fandom@retemail.es
+## (c) 2002-2003 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -27,9 +27,12 @@ proc EnterUrlChangeDir {} {
 
     if {$dirGetleft(chDir)!=$env(HOME)} {
         set currentDir [file dirname $dirGetleft(chDir)]
+    } else {
+        set currentDir $env(HOME)
     }
 
-    set dirGetleft(baseDir) [Dialogos::SelectDirectory $currentDir .enterUrlWindow]
+    set dirGetleft(baseDir) [Dialogos::SelectDirectory                     \
+            $currentDir .enterUrlWindow]
 
     if {$dirGetleft(baseDir)!=""} {
         set dirGetleft(chDir)   [file nativename $dirGetleft(baseDir)]
@@ -49,10 +52,13 @@ proc EnterUrlChangeDir {} {
 #
 # Returns:
 #    The path of the entry in the combobox.
-###############################################################################
+################################################################################
 proc EnterUrlWindow {parent url} {
     global labelButtons labelTitles labelFrames labelDialogs labelMenus
     global urlHistory getleftState getleftOptions dirGetleft
+    global indexButtons indexDialogs
+    variable window
+
     set coord(x) [winfo rootx $parent]
     set coord(y) [winfo rooty $parent]
 
@@ -62,64 +68,77 @@ proc EnterUrlWindow {parent url} {
     wm geometry  $win +[expr {$coord(x)+100}]+[expr {$coord(y)+15}]
 
     set marcoEx [frame $win.marcoEx]
-    set marcoUrl [fl::FrameLabel $marcoEx.marco -bd 2 -relief groove \
+    set marcoUrl [fl::FrameLabel $marcoEx.marco -bd 2 -relief groove                      \
             -textvariable labelFrames(webPage)]
     set marcoUrlIn [frame $marcoUrl.marcoIn]
     if {$url==""} {
         set url [menuEntry::ReadSel]
     }
-    Ccombinado::ComboBox $marcoUrlIn.pagina $urlHistory -erasable 1  \
-            -default $url -fg $getleftOptions(fg) -bg $getleftOptions(bg)
-    set startCheck [checkbutton $marcoUrlIn.start -variable getleftState(startNow) \
-        -textvariable labelDialogs(startNow)]
+    set window(url) $url
+    set urlCombo [Ccombinado::ComboBox $marcoUrlIn.url $urlHistory                        \
+            -erasable 1  -default $url -fg $getleftOptions(fg)                            \
+            -bg $getleftOptions(bg) -textvariable EnterUrl::window(url)]
+    set startCheck [underButton::UnderButton $marcoUrlIn.start -buttontype checkbutton    \
+            -variable getleftState(startNow)                                              \
+            -textvariable labelDialogs(startNow) -under $indexDialogs(startNow)]
 
-    set dirFrame    [fl::FrameLabel $marcoEx.dirFrame -bd 2 -relief groove \
+    set dirFrame    [fl::FrameLabel $marcoEx.dirFrame -bd 2 -relief groove                \
             -textvariable labelFrames(dir)]
     set dirIntFrame [frame $dirFrame.intFrame]
-    set dirEntry [menuEntry::menuEntry $dirIntFrame.entry -width 40 -bg $getleftOptions(bg) \
-            -fg $getleftOptions(fg) -textvariable dirGetleft(chDir)]
-    set dirButton [button $dirIntFrame.button -textvariable labelButtons(select) -width 10  \
-            -command "EnterUrl::EnterUrlChangeDir"]
+    set dirEntry [menuEntry::menuEntry $dirIntFrame.entry -width 40                       \
+            -bg $getleftOptions(bg) -fg $getleftOptions(fg)                               \
+            -textvariable dirGetleft(chDir)]
+
+    set dirButton [underButton::UnderButton $dirIntFrame.button -buttontype button        \
+            -width 10 -command "EnterUrl::EnterUrlChangeDir"                              \
+            -textvariable labelButtons(select) -under $indexButtons(select)               \
+            ]
     set dirGetleft(chDir)   [file nativename $dirGetleft(lastDir)]
 
     $dirEntry xview moveto 1.0
 
-    set pagina $marcoUrlIn.pagina
     set buttons [frame $win.buttons]
-    set start   [button $buttons.start   -textvariable labelButtons(start)  \
-            -width 8 -command "EnterUrl::EnterUrlControl $pagina.entry $dirEntry 1"]
-    set cancel  [button $buttons.cancel  -textvariable labelButtons(cancel) \
-            -width 8 -command "EnterUrl::EnterUrlControl $pagina.entry $dirEntry 0"]
+    set start   [underButton::UnderButton $buttons.start   -textvariable labelButtons(start)  \
+            -width 8 -command "EnterUrl::EnterUrlControl 1" -under $indexButtons(start)       \
+            -buttontype button ]
+    set cancel  [underButton::UnderButton $buttons.cancel  -textvariable labelButtons(cancel) \
+            -width 8 -command "EnterUrl::EnterUrlControl 0" -under $indexButtons(cancel)      \
+            -buttontype button ]
+    set options [underButton::UnderButton $buttons.options -textvariable labelButtons(options)\
+            -width 8 -command "Opciones::ChooseOptions ::downOptionsTemp $win"                \
+            -buttontype button  -under $indexButtons(options)]
 
-    set options [button $buttons.options -textvariable labelButtons(options)\
-            -width 8 -command "Opciones::ChooseOptions ::downOptionsTemp $win"]
 
-    bind $pagina.entry <Return>   "focus $dirEntry"
-    bind $pagina.entry <KP_Enter> "focus $dirEntry"
+    set window(win)      $win
+    set window(combo)    $urlCombo
+    set window(dirEntry) $dirEntry
 
-    bind $dirEntry     <Return>   "focus $start"
-    bind $dirEntry     <KP_Enter> "focus $start"
+    bind $urlCombo.entry <Return>   "focus $dirEntry"
+    bind $urlCombo.entry <KP_Enter> "focus $dirEntry"
 
-    bind $win <Escape> "$cancel invoke"
+    bind $dirEntry       <Return>   "focus $start"
+    bind $dirEntry       <KP_Enter> "focus $start"
+
+    bind $win            <Escape>   "$cancel invoke"
 
     pack $marcoEx     -padx 10
 
     pack $marcoUrl    -ipady 10 -pady 10 -fill x
     pack $marcoUrlIn  -side bottom -padx 20
-    pack $pagina   
-    pack $startCheck -pady 5 -side left
+    pack $urlCombo   
+    pack $startCheck  -pady 5 -side left
 
-    pack $dirFrame    -ipady 10 -fill both
-    pack $dirIntFrame -side left -fill x    -padx 20
-    pack $dirEntry    -side left -pady 5
-    pack $dirButton   -side left -padx 5 
+    pack $dirFrame    -ipady 10    -fill both
+    pack $dirIntFrame -side left   -fill x    -padx 20
+    pack $dirEntry    -side left   -pady 5
+    pack $dirButton   -side left   -padx 5 
 
-    pack $buttons  -side bottom -padx 7 -fill x
+    pack $buttons     -side bottom -padx 7 -fill x
     pack $cancel $start $options -side right -padx 3 -pady 5
 
-    focus $pagina.entry
+    focus $urlCombo.entry
 
-    return $pagina.entry
+    return $urlCombo.entry
 }
 
 ###############################################################################
@@ -128,42 +147,39 @@ proc EnterUrlWindow {parent url} {
 #    In practice, in considers just about anything to be valid.
 #
 # Parameter
-#    comboEntry: The path of the entry where the url is.
-#    dirEntry:   The path of the entry for the directory.
-#    done:       '1' if the user clicked on start, '0' if he cancelled.
-###############################################################################
-proc EnterUrlControl {comboEntry dirEntry done} {
+#    done: '1' if the user clicked on start, '0' if he cancelled.
+################################################################################
+proc EnterUrlControl {done} {
     global labelTitles labelMessages
     global dirGetleft  directories getleftState
+    variable window
 
-    catch {$comboEntry get} requestedUrl 
-
-    if {($done==0)||($requestedUrl=="")} {
-        destroy .enterUrlWindow
+    if {($done==0)||($window(url)=="")} {
+        wm withdraw $window(win)
         return
     }
 
-    set requestedUrl [string trim $requestedUrl]
+    set requestedUrl [string trim $window(url)]
     set parsedUrl    [HtmlParser::ParseUrl $requestedUrl]
 
-    if {($parsedUrl==1)||([regexp {\s} $requestedUrl])} {
-        tk_messageBox -title $labelTitles(error) -icon error -type ok \
-                -message "$labelMessages(noWWW)\n$requestedUrl"       \
-                -parent .enterUrlWindow 
+    if {$parsedUrl==1} {
+        tk_messageBox -title $labelTitles(error) -icon error -type ok         \
+                -message "$labelMessages(noWWW)\n$requestedUrl"               \
+                -parent $window(win)
         return
     }
 
-    set dir [$dirEntry get]
+    set dir $dirGetleft(chDir)
     if {$dir==""} {
-        tk_messageBox -type ok -icon error -title $labelTitles(error) \
-                -message "Please, enter a directory" -parent .enterUrlWindow
+        tk_messageBox -type ok -icon error -title $labelTitles(error)         \
+                -message "Please, enter a directory" -parent $window(win)
         return
     }
     regsub -all {\\} $dir {/} dirGetleft(baseDir)
     if {![file exists $dirGetleft(baseDir)]} {
-       set what [tk_messageBox -icon question \
-            -message $labelMessages(unknown) -title $labelTitles(unknown) \
-            -parent .enterUrlWindow -type yesno]
+       set what [tk_messageBox -icon question                                 \
+            -message $labelMessages(unknown) -title $labelTitles(unknown)     \
+            -parent $window(win) -type yesno]
        switch $what {
             yes {
                 file mkdir $dirGetleft(baseDir)
@@ -172,13 +188,12 @@ proc EnterUrlControl {comboEntry dirEntry done} {
 	  }
     } else {
        if {![file isdirectory $dirGetleft(baseDir)]} {
-           tk_messageBox -type ok -icon error -title $labelTitles(error) \
-                    -message "Please, enter a directory" -parent .enterUrlWindow
+           tk_messageBox -type ok -icon error -title $labelTitles(error)     \
+                    -message "Please, enter a directory" -parent $window(win)
            return
        }
     }
-
-    destroy .enterUrlWindow
+    wm withdraw $window(win)
 
     regsub -all {\n}   $requestedUrl {}  requestedUrl
     regsub -all {\\}   $requestedUrl {/} requestedUrl
@@ -208,18 +223,30 @@ proc EnterUrlControl {comboEntry dirEntry done} {
 ###############################################################################
 proc EnterUrl {{map 0} {parent .} {url ""}} {
     global getleftOptions downOptions downOptionsTemp
+    variable window
 
     if {[winfo exists .enterUrlWindow]} {
-        focus .enterUrlWindow
-        return
+        raise $window(win) .
+        if {[wm state $window(win)]!="withdrawn"} {
+            return
+        }
     }
 
     catch "unset ::downOptionsTemp"
     array set downOptionsTemp [array get downOptions]
     set downOptionsTemp(map) $map
 
-    EnterUrlWindow $parent $url
-
+    if {![winfo exists .enterUrlWindow]} {
+        EnterUrlWindow $parent $url
+    } else {
+        if {$url!=""} {
+            set window(url) $url
+        } else {
+            set window(url) [menuEntry::ReadSel]
+        }
+        set Ccombinado::cbArgs(items) $::urlHistory
+        wm state $window(win) normal
+    }
     return
 }
 
