@@ -15,7 +15,7 @@
 namespace eval Herramientas {
 
 ###############################################################################
-# ExtensionsDialog
+# ExtensionDialog
 #    Creates a dialog box to choose file extensions
 #
 # Parameters:
@@ -30,7 +30,7 @@ namespace eval Herramientas {
 #    1: if cancelled
 ###############################################################################
 proc ExtensionDialog {title parent {filter ""}} {
-    global labelButtons labelTitles downOptions
+    global labelButtons labelTitles downOptions indexButtons
     variable done
 
     set coord(x) [winfo rootx $parent]
@@ -45,33 +45,40 @@ proc ExtensionDialog {title parent {filter ""}} {
     set marcoInt [frame $marcoExt.marcoInt -bd 2 -relief groove]
     set marcoBot [frame $win.marcoBot]
 
-    set izqBot1  [checkbutton $marcoInt.bot1 -variable ::Herramientas::bot(1) \
+    set izqBot1  [checkbutton $marcoInt.bot1  -variable ::Herramientas::bot(1) \
             -onvalue "jpg" -offvalue "" -text "*.jpg"]
-    set izqBot2  [checkbutton $marcoInt.bot2 -variable ::Herramientas::bot(2) \
+    set izqBot2  [checkbutton $marcoInt.bot2  -variable ::Herramientas::bot(2) \
             -onvalue "gif" -offvalue "" -text "*.gif"]
-    set izqBot3  [checkbutton $marcoInt.bot3 -variable ::Herramientas::bot(3) \
+    set izqBot3 [checkbutton  $marcoInt.bot3  -variable ::Herramientas::bot(3) \
+            -onvalue "mp3" -offvalue "" -text "*.mp3"]
+    set izqBot4  [checkbutton $marcoInt.bot4  -variable ::Herramientas::bot(4) \
             -onvalue "ps"  -offvalue "" -text "*.ps" ]
 
-    set cenBot1  [checkbutton $marcoInt.bot4 -variable ::Herramientas::bot(4) \
+    set cenBot1  [checkbutton $marcoInt.bot5  -variable ::Herramientas::bot(5) \
             -onvalue "pdf" -offvalue "" -text "*.pdf"]
-    set cenBot2  [checkbutton $marcoInt.bot5 -variable ::Herramientas::bot(5) \
+    set cenBot2  [checkbutton $marcoInt.bot6  -variable ::Herramientas::bot(6) \
             -onvalue "txt" -offvalue "" -text "*.txt"]
-    set cenBot3  [checkbutton $marcoInt.bot6 -variable ::Herramientas::bot(6) \
+    set cenBot3  [checkbutton $marcoInt.bot7  -variable ::Herramientas::bot(7) \
             -onvalue "mov" -offvalue "" -text "*.mov"]
+    set cenBot4  [checkbutton $marcoInt.bot8  -variable ::Herramientas::bot(8) \
+            -onvalue "mpg" -offvalue "" -text "*.mpg"]
 
-    set derBot1  [checkbutton $marcoInt.bot7 -variable ::Herramientas::bot(7) \
+    set derBot1  [checkbutton $marcoInt.bot9  -variable ::Herramientas::bot(9) \
             -onvalue "avi" -offvalue "" -text "*.avi"]
-    set derBot2  [checkbutton $marcoInt.bot8 -variable ::Herramientas::bot(8) \
+    set derBot2  [checkbutton $marcoInt.bot10 -variable ::Herramientas::bot(10)\
             -onvalue "zip" -offvalue "" -text "*.zip"]
-    set derBot3  [checkbutton $marcoInt.bot9 -variable ::Herramientas::bot(9) \
+    set derBot3  [checkbutton $marcoInt.bot11 -variable ::Herramientas::bot(11)\
             -onvalue "tgz" -offvalue "" -text "*.tgz"]
+    set derBot4  [checkbutton $marcoInt.bot12 -variable ::Herramientas::bot(12)\
+            -onvalue "sit" -offvalue "" -text "*.sit"]
+
 
     if {![string match $title $labelTitles(exclude)]} {
-        foreach {index ext} {1 jpg 2 gif 3 ps 4 pdf 5 txt 6 mov 7 avi 8 zip 9 tgz} {
+        foreach {index ext} {1 jpg 2 gif 3 mp3 4 ps 5 pdf 6 txt 7 mov 8 mpg 9 avi 10 zip 11 tgz 12 sit} {
             set ::Herramientas::bot($index) $ext
         }
     } else {
-        foreach {index ext} {1 jpg 2 gif 3 ps 4 pdf 5 txt 6 mov 7 avi 8 zip 9 tgz} {
+        foreach {index ext} {1 jpg 2 gif 3 mp3 4 ps 5 pdf 6 txt 7 mov 8 mpg 9 avi 10 zip 11 tgz 12 sit} {
             if {[regexp "$ext" $filter]} {
                 set ::Herramientas::bot($index) $ext
             } else {
@@ -80,9 +87,11 @@ proc ExtensionDialog {title parent {filter ""}} {
         }
     }
 
-    set aceptar  [button $marcoBot.aceptar  -textvariable labelButtons(ok)    \
+    set aceptar  [underButton::UnderButton $marcoBot.aceptar  -buttontype button\
+        -textvariable labelButtons(ok)     -under $indexButtons(ok)             \
 		-width 8 -command "set ::Herramientas::done 1"]
-    set cancelar [button $marcoBot.cancelar -textvariable labelButtons(cancel)\
+    set cancelar [underButton::UnderButton $marcoBot.cancelar -buttontype button\                 \
+        -textvariable labelButtons(cancel) -under $indexButtons(cancel)         \
 		-width 8 -command "set ::Herramientas::done 0"]
 
     bind $win <Escape> "$cancelar invoke"
@@ -93,6 +102,7 @@ proc ExtensionDialog {title parent {filter ""}} {
     grid $izqBot1 $cenBot1 $derBot1 -sticky w -padx 3
     grid $izqBot2 $cenBot2 $derBot2 -sticky w -padx 3
     grid $izqBot3 $cenBot3 $derBot3 -sticky w -padx 3
+    grid $izqBot4 $cenBot4 $derBot4 -sticky w -padx 3
 
     pack $marcoBot -fill x -padx 7
     pack $cancelar $aceptar  -side right -pady 5 -padx 3
@@ -154,7 +164,7 @@ proc PurgeFiles {} {
     global labelTitles labelMessages dirGetleft
 
     if {[winfo exists .extDialog]} {
-        focus .extDialog
+        raise .extDialog .
         return
     }
 
@@ -163,17 +173,22 @@ proc PurgeFiles {} {
     }
 
     set dir [Dialogos::SelectDirectory $dirGetleft(toolDir)]
-#    set dir [tk_chooseDirectory]
     if {![string compare $dir ""]} {
         return
     }
     set dirGetleft(toolDir) [file dirname $dir]
 
     set dirTmp [pwd]
-    for {set i 1;set purgarCmd ""} {$i<10} {incr i} {
+    for {set i 1;set purgarCmd ""} {$i<13} {incr i} {
+        if {$::Herramientas::bot($i)=="tgz"} {
+            append purgarCmd tar.gz " "
+        } elseif {$::Herramientas::bot($i)=="jpg"} {
+            append purgarCmd jpeg   " "
+        } elseif {$::Herramientas::bot($i)=="mpg"} {
+            append purgarCmd mpeg   " "
+        }
         append purgarCmd $::Herramientas::bot($i) " "
     }
-
     PurgeFilesDir $dir $purgarCmd
 
     tk_messageBox -title $labelTitles(theEnd) -icon info \
@@ -382,33 +397,34 @@ proc ConfProxyControl {action {parent .proxy}} {
 #    The widget in which it will be put.
 ###############################################################################
 proc ConfProxyWindowCommon {parent} {
-    global getleftOptions
+    global getleftOptions indexDialogs
     variable ip
     variable authen
 
     set marcoEx   [frame $parent.marcoEx]
     set marcoIn   [frame $marcoEx.marcoIn]
-    set marcoIp   [fl::FrameLabel $marcoIn.marcoIp   -bd 2 -relief groove\
+    set marcoIp   [fl::FrameLabel $marcoIn.marcoIp   -bd 2 -relief groove           \
             -textvariable  labelFrames(proxy)]
 
     set label1 [label $marcoIp.label1 -textvariable labelDialogs(http)]
-    set ip(1)  [entry $marcoIp.1 -width 20 -bg $getleftOptions(bg) \
+    set ip(1)  [entry $marcoIp.1 -width 20 -bg $getleftOptions(bg)                  \
                     -fg $getleftOptions(fg) -justify  left]
-    set ip(2)  [entry $marcoIp.2 -width 4  -bg $getleftOptions(bg) \
+    set ip(2)  [entry $marcoIp.2 -width 4  -bg $getleftOptions(bg)                  \
                     -fg $getleftOptions(fg)]
     set colon1 [label $marcoIp.colon1 -text : -width 2]
 
     set label2 [label $marcoIp.label2  -textvariable labelDialogs(ftp)]
-    set ip(3)  [entry $marcoIp.3 -width 20 -bg $getleftOptions(bg) \
+    set ip(3)  [entry $marcoIp.3 -width 20 -bg $getleftOptions(bg)                  \
                     -fg $getleftOptions(fg) -justify  left]
-    set ip(4)  [entry $marcoIp.4 -width 4  -bg $getleftOptions(bg) \
+    set ip(4)  [entry $marcoIp.4 -width 4  -bg $getleftOptions(bg)                  \
                     -fg $getleftOptions(fg)]
     set colon2 [label $marcoIp.colon2 -text : -width 2]
 
-    set checkIp [checkbutton $marcoIp.check -textvariable labelDialogs(sameProxy) \
+    set checkIp [underButton::UnderButton $marcoIp.check -buttontype checkbutton    \
+            -textvariable labelDialogs(sameProxy) -under $indexDialogs(sameProxy)   \
             -variable getleftOptions(sameProxy) -command ::Herramientas::SameProxy]
 
-    set marcoAuth    [fl::FrameLabel $marcoIn.marcoAuth -bd 2 -relief groove \
+    set marcoAuth    [fl::FrameLabel $marcoIn.marcoAuth -bd 2 -relief groove        \
             -textvariable labelFrames(authen)]
     set nameLabel    [label $marcoAuth.nameLabel -textvariable labelDialogs(username)]
     set authen(name) [entry $marcoAuth.nameEntry -width 15  -bg $getleftOptions(bg) \
@@ -417,9 +433,13 @@ proc ConfProxyWindowCommon {parent} {
     set authen(pass) [entry $marcoAuth.passEntry -width 15  -bg $getleftOptions(bg) \
             -fg $getleftOptions(fg) -show *]
 
-    set authen(use)  [checkbutton $marcoAuth.use  -command Herramientas::AuthenProxy \
+    set authen(use)  [underButton::UnderButton $marcoAuth.use                       \
+        -command Herramientas::AuthenProxy -buttontype checkbutton                  \
+        -under $indexDialogs(authenUse)                                             \
         -textvariable labelDialogs(authenUse) -variable getleftOptions(useAuthProxy)]
-    set authen(save) [checkbutton $marcoAuth.save -command Herramientas::AuthenProxy \
+    set authen(save) [underButton::UnderButton $marcoAuth.save                      \
+        -under $indexDialogs(authenSave) -buttontype checkbutton                    \
+        -command Herramientas::AuthenProxy                                          \
         -textvariable labelDialogs(authenSave) -variable getleftOptions(saveAuthPass)]
 
     grid $marcoEx -padx 7    -ipady 5
@@ -481,7 +501,7 @@ proc ConfProxyWindowCommon {parent} {
 #    Creates the window in which the user enters his proxy data.
 ###############################################################################
 proc ConfProxyWindow {} {
-    global labelTitles
+    global labelTitles indexButtons
 
     set coord(x) [winfo rootx .]
     set coord(y) [winfo rooty .]
@@ -494,15 +514,20 @@ proc ConfProxyWindow {} {
     ConfProxyWindowCommon $proxy
 
     set botones  [frame  $proxy.marcoEx.botones]
-    set borrar   [button $botones.borrar   -textvariable labelButtons(clear) \
+    set clear  [underButton::UnderButton $botones.clear -buttontype button  \
+            -textvariable labelButtons(clear)  -under $indexButtons(clear)  \
             -width 8 -command {::Herramientas::ConfProxyControl clear}]
-    set aceptar  [button $botones.aceptar  -textvariable labelButtons(ok)    \
+    set accept [underButton::UnderButton $botones.accept -buttontype button \
+            -textvariable labelButtons(ok)     -under $indexButtons(ok)     \
             -width 8 -command {::Herramientas::ConfProxyControl accept}]
-    set cancelar [button $botones.cancelar -textvariable labelButtons(cancel)\
+    set cancel [underButton::UnderButton $botones.cancel -buttontype button \
+            -textvariable labelButtons(cancel) -under $indexButtons(cancel) \
             -width 8 -command {::Herramientas::ConfProxyControl cancel}]
 
+    bind $proxy <Escape> "$cancel invoke"
+
     grid $botones -sticky e -padx 2
-    grid $borrar $aceptar $cancelar $aceptar -padx 3 -sticky n
+    grid $clear $accept $cancel -padx 3 -sticky n
 
     return
 }
@@ -516,7 +541,7 @@ proc ConfProxy {} {
     variable getleftOptionsTemp
 
     if {[winfo exists .proxy]} {
-        focus .proxy
+        raise .proxy .
         return
     }
 
@@ -628,7 +653,7 @@ proc GetPass {} {
     global getleftOptions
 
     if {[winfo exists .getPass]} {
-        focus .getPass
+        raise .getPass .
         return
     }
 
@@ -662,7 +687,7 @@ proc FilterFiles {filter {parent .}} {
     global labelTitles
 
     if {[winfo exists .extDialog]} {
-        focus .extDialog
+        raise .extDialog .
         return $filter
     }
 
@@ -670,12 +695,14 @@ proc FilterFiles {filter {parent .}} {
         return $filter
     }
     catch {unset urlsDownloaded}
-    for {set i 1;set filter ""} {$i<10} {incr i} {
+    for {set i 1;set filter ""} {$i<13} {incr i} {
         if {$::Herramientas::bot($i)!=""} {
             if {$::Herramientas::bot($i)=="tgz"} {
                 append filter (tar.gz$) "|"
             } elseif {$::Herramientas::bot($i)=="jpg"} {
                 append filter (jpeg$) "|"
+            } elseif {$::Herramientas::bot($i)=="mpg"} {
+                append filter (mpeg$) "|"
             }
             append filter ($::Herramientas::bot($i)$) "|"
         }
