@@ -6,7 +6,7 @@
 # In this file are implemented the procedures used to parse Html file links.
 ###############################################################################
 ###############################################################################
-# Copyright 2000 Andrs Garca Garca  -- fandom@retemail.es
+# Copyright 2000-2003 Andrs Garca Garca  -- fandom@retemail.es
 # Distributed under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -355,8 +355,12 @@ proc GetFileName {tag type} {
         if {[regexp -nocase {^javascript:} $fileName]} {
             return 1
         }
+        if {[regexp -nocase {^mailto:|^news:} $fileName]} {
+            return 1
+        }
         return $fileName
     }
+    # If the link happens to be written like: <a href="">index.html</a>
     if {[regexp -nocase [subst -nocommand {(?:$type=)((\"\")|(\'\'))}] $tag]} {
         return ""
     }
@@ -366,7 +370,7 @@ proc GetFileName {tag type} {
 ###############################################################################
 # CompleteString
 #    Reads from the channel 'leer' until the 'cosa' string includes the
-#    substring passed as a parameter.
+#    substring passed as a parameter. 
 #
 # Parameters:
 #    cadena: name of the variable with the string to complete.
@@ -385,7 +389,7 @@ proc CompleteString {cadena leer pattern} {
     upvar $cadena cosa
     for {set tmp [gets $leer]} {![eof $leer]} {set tmp [gets $leer]} {
         append cosa " " $tmp
-        if {[regexp -nocase "$pattern" $tmp]} {
+        if {[regexp -nocase [subst -nocommand {$pattern}] $tmp]} {
             return 0
         }
     }
@@ -410,7 +414,7 @@ proc CompleteString {cadena leer pattern} {
 #    'links' : keeps all the info about the links.
 ###############################################################################
 proc Parsing {file referer} {
-    global   labelDialogs labelTitles
+    global   labelDialogs labelTitles getleftOptions
     variable nLinks
     variable links
     variable pageEncoding
@@ -427,15 +431,14 @@ proc Parsing {file referer} {
     catch {unset linkType}
     set pageEncoding ""
 
-    for {set cosa [gets $leer] ; set thumbnailNext 0 ; set newBase "" ; set baseTag ""} \
+    for {set cosa ""; set thumbnailNext 0 ; set newBase "" ; set baseTag ""} \
             {(![eof $leer]) || ([string compare $cosa ""])} \
             {if {![eof $leer]} {append cosa " " [gets $leer] " "} } {
-        if {![regexp {(<)(.*)} $cosa cosa]} {
-            set cosa ""
-            continue
+        if {$getleftOptions(pauseNow)==1} {
+            tkwait variable getleftOptions(pauseNow)
         }
         if {![regexp -nocase {(<)(a|b|l|i|f|s|m)(.*)} $cosa cosa]} {
-            set cosa ""
+            set cosa [gets $leer] 
             continue
         }
         if {![regexp {>} $cosa]} {
@@ -443,8 +446,8 @@ proc Parsing {file referer} {
             if {$result==1} break
         }
         regexp {(?:<)([^>]*)(?:>)(.*)} $cosa nada tag cosa
-        set lowerTag [string tolower $tag]
 
+        set lowerTag [string tolower $tag]
         if {![regexp {^(a.+h|link|img|frame|area|form|script|meta|base)} $lowerTag ]} {
             continue
         }
@@ -475,23 +478,26 @@ proc Parsing {file referer} {
             }
             "^a.+href" {
                 if {[set fileName [GetFileName $tag href]]!=1} {
-                    if {[regexp -nocase {^mailto:|^news:} $fileName]} continue
                     if {[regexp -nocase {(javascript)(.*)(\()} $fileName]} continue
-                    if {![regexp -nocase {(</a)} $cosa]} {
-                        set result [CompleteString cosa $leer "</a"]
+                    if {![regexp -nocase {(<)((/a)|(a))} $cosa]} {
+                        # It so happens you can skip closing the link, browsers
+                        # consider them closed if you open another one.
+                        set result [CompleteString cosa $leer {(<)((/a)|(a))}]
                         if {$result==1} break
                     }
-                    regexp -nocase {(.*?)(?:</a)} $cosa nada descripcion
+                    regexp -nocase {(.*?)(?:(<)((/a)|(a)))} $cosa nada descripcion
                     set links($nLinks,descrip) $descripcion
                     if {[string match $descripcion ""]} {
                         set fileName 1
                     }
                     if {[regexp -nocase {<img[^>]* src} $descripcion]} {
                         set thumbnailNext 1
+                    } else {
+                        regexp {(.*?)(<)} $descripcion descripcion
                     }
                 }
             }
-            "^link +href" {
+            "^link.+href" {
                 if {[set fileName [GetFileName $tag href]]!=1} {
                     set links($nLinks,descrip) "$labelDialogs(css)"
                 }
@@ -533,7 +539,7 @@ proc Parsing {file referer} {
         }
     }
     close $leer
- 
+
     return 0
 }
 
@@ -558,8 +564,7 @@ proc FilterLinks {referer linkArray} {
 
     for {set i 1} {[info exists links($i,url)]} {incr i} {
         set link $links($i,url)
-		set links($i,ok) 1
-
+        set links($i,ok) 1
         if {([regexp {\.ram$} $link])} {
             set links($i,ok) 0
             continue
@@ -619,7 +624,7 @@ proc FilterLinks {referer linkArray} {
 
         catch {
             if {($links([expr {$i+1}],type)=="thumb")&&($downOptions(images)==1)} {
-                if {[regexp -nocase {(gif$)|(jpg$)|(bmp$)|(xbm$)|(tiff$)|(png$)}\
+                if {[regexp -nocase {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff$)|(png$)}\
 						$links($i,file)]} {
                     set remove 1
                 }
@@ -636,6 +641,7 @@ proc FilterLinks {referer linkArray} {
             continue
         }
     }
+
     return
 }
 
@@ -684,6 +690,7 @@ proc CompleteUrl {link referer newBase} {
     }
     set fileName [TidyDir $dir/$link]
     set url "$prot://$domain$fileName"
+
     return $url
 }
 
