@@ -6,7 +6,7 @@
 ## Creates a dialog in which to choose the options for the program
 ###############################################################################
 ###############################################################################
-## (c) 2001 Andrs Garca Garca. fandom@retemail.es
+## (c) 2001-2003 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -27,26 +27,22 @@ proc UpdateSpinBox {which} {
     if {$which=="internal"} {
         if {$optionsTemp(limitLevels)==1} {
             CuadroSpin::EnableSpin $window(intSpin) normal
-            if {$optionsTemp(levels)==-1} {
-                set CuadroSpin::CuadroSpins($window(intSpin)) 1
-            } else {
-                set CuadroSpin::CuadroSpins($window(intSpin)) $optionsTemp(levels)
+            if {$optionsTemp(levels)==0} {
+                set optionsTemp(levels) 1
             }
         } else {
             CuadroSpin::EnableSpin $window(intSpin) disable
-            set CuadroSpin::CuadroSpins($window(intSpin)) 0
+            set optionsTemp(levels) 0
         }
     } else {
         if {$optionsTemp(external)==1} {
             CuadroSpin::EnableSpin $window(extSpin) normal
             if {$optionsTemp(exLevels)==0} {
-                set CuadroSpin::CuadroSpins($window(extSpin)) 1
-            } else {
-                set CuadroSpin::CuadroSpins($window(extSpin)) $optionsTemp(exLevels)
+                set optionsTemp(exLevels) 1
             }
         } else {
             CuadroSpin::EnableSpin $window(extSpin) disable
-            set CuadroSpin::CuadroSpins($window(extSpin)) 0
+            set optionsTemp(exLevels) 0
         }
     }
     return
@@ -71,7 +67,6 @@ proc SetDefaultOptions {optionsToSet} {
     } else {
         set options(limitLevels) 1
     }
-
     return
 }
 
@@ -84,7 +79,9 @@ proc SaveDefaultOptions {} {
     variable optionsTemp
 
     array set defaultDownOptions [array get optionsTemp]
-
+    if {$optionsTemp(limitLevels)==0} {
+        set defaultDownOptions(levels) -1
+    }
     return
 }
 
@@ -141,13 +138,14 @@ proc ChangeFilter {} {
 ###############################################################################
 proc ChooseOptionsWindow {parent} {
     global labelTitles labelButtons labelDialogs labelFrames getleftOptions
-    global dirGetleft
+    global dirGetleft indexButtons indexDialogs
     variable optionsTemp
     variable done
     variable window
 
     if {[winfo exists .optionsWin]} {
-        focus $window(win)
+        wm state $window(win) normal
+        raise $window(win)
         return
     } 
 
@@ -163,74 +161,89 @@ proc ChooseOptionsWindow {parent} {
     set intFrame  [frame $extFrame.intFrame]
     set butFrame  [frame $extFrame.butFrame]
 
-    set linkFrame [fl::FrameLabel $intFrame.links -bd 2 -relief groove  \
+    set linkFrame [fl::FrameLabel $intFrame.links -bd 2 -relief groove         \
             -textvariable labelFrames(links)]
     set intLinks    [frame $linkFrame.int]
-    set updirLinks  [checkbutton $intLinks.updirLinks      \
-        -variable Opciones::optionsTemp(dir) -textvariable labelDialogs(uplinks)]
-    set updateLinks [checkbutton $intLinks.updateLinks     \
-        -variable Opciones::optionsTemp(update) -textvariable labelDialogs(update)]
-    set cgiLinks    [checkbutton $intLinks.cgiLinks        \
-        -variable Opciones::optionsTemp(cgi) -textvariable labelDialogs(cgi)]
+    set updirLinks  [underButton::UnderButton $intLinks.updirLinks             \
+            -buttontype checkbutton -variable Opciones::optionsTemp(dir)       \
+            -textvariable labelDialogs(uplinks) -under $indexDialogs(uplinks)]
+    set updateLinks [underButton::UnderButton $intLinks.updateLinks            \
+            -buttontype checkbutton -under $indexDialogs(update)               \
+            -variable Opciones::optionsTemp(update)                            \
+            -textvariable labelDialogs(update)]
+    set cgiLinks    [underButton::UnderButton $intLinks.cgiLinks               \
+            -variable Opciones::optionsTemp(cgi) -buttontype checkbutton       \
+            -textvariable labelDialogs(cgi) -under $indexDialogs(cgi)]
 
-    set levelFrame [fl::FrameLabel $intFrame.levels -bd 2 -relief groove \
+    set levelFrame [fl::FrameLabel $intFrame.levels -bd 2 -relief groove       \
             -textvariable labelFrames(levels)]
     set intLevels  [frame $levelFrame.int]
-    set internal   [checkbutton $intLevels.internal    \
-        -variable Opciones::optionsTemp(limitLevels)   \
-        -textvariable labelDialogs(levels)             \
-        -command "Opciones::UpdateSpinBox internal"]
-    set external   [checkbutton $intLevels.external    \
-        -variable Opciones::optionsTemp(external)      \
-        -textvariable labelDialogs(external)           \
-        -command "Opciones::UpdateSpinBox external"]
-    set intSpin [CuadroSpin::CuadroSpin $intLevels.intspin     \
-            -default 0 -min 0 -max 5 -width 3                  \
-            -bg $getleftOptions(bg) -fg $getleftOptions(fg)    \
-            -disbg $getleftOptions(disBg)                      \
-            -disfg $getleftOptions(disFg)]
-    set extSpin [CuadroSpin::CuadroSpin $intLevels.extspin     \
-            -default 0 -min 0 -max 3 -width 3                  \
-            -bg $getleftOptions(bg) -fg $getleftOptions(fg)    \
-            -disbg $getleftOptions(disBg)                      \
-            -disfg $getleftOptions(disFg)]
+    set internal   [underButton::UnderButton $intLevels.internal               \
+            -variable Opciones::optionsTemp(limitLevels)                       \
+            -buttontype checkbutton  -under $indexDialogs(levels)              \
+            -textvariable labelDialogs(levels)                                 \
+            -command "Opciones::UpdateSpinBox internal"]
+    set external   [underButton::UnderButton $intLevels.external               \
+            -variable Opciones::optionsTemp(external) -buttontype checkbutton  \
+            -textvariable labelDialogs(external) -under $indexDialogs(external)\
+            -command "Opciones::UpdateSpinBox external"]
+    set intSpin [CuadroSpin::CuadroSpin $intLevels.intspin                     \
+            -default 0 -min 0 -max 5 -width 3                                  \
+            -bg $getleftOptions(bg)       -fg    $getleftOptions(fg)           \
+            -disbg $getleftOptions(disBg) -disfg $getleftOptions(disFg)        \
+            -textvariable Opciones::optionsTemp(levels)]
+    set extSpin [CuadroSpin::CuadroSpin $intLevels.extspin                     \
+            -default 0 -min 0 -max 3 -width 3                                  \
+            -bg $getleftOptions(bg)       -fg    $getleftOptions(fg)           \
+            -disbg $getleftOptions(disBg) -disfg $getleftOptions(disFg)        \
+            -textvariable Opciones::optionsTemp(exLevels)]
 
-    set imageFrame   [fl::FrameLabel $intFrame.image   -bd 2 -relief groove  \
+    set imageFrame   [fl::FrameLabel $intFrame.image   -bd 2 -relief groove    \
             -textvariable labelFrames(images)]
     set intImages    [frame $imageFrame.int]
-    set all          [radiobutton $intImages.all        -value 0    \
-            -textvariable labelDialogs(allImages)                   \
+    set all          [underButton::UnderButton $intImages.all        -value 0  \
+            -textvariable labelDialogs(allImages)   -buttontype radiobutton    \
+            -under $indexDialogs(allImages)                                    \
             -variable Opciones::optionsTemp(images)]
-    set onlyThumbs   [radiobutton $intImages.onlyThumbs -value 1    \
-            -variable Opciones::optionsTemp(images)                 \
+    set onlyThumbs   [underButton::UnderButton $intImages.onlyThumbs -value 1  \
+            -variable Opciones::optionsTemp(images) -buttontype radiobutton    \
+            -under $indexDialogs(onlyThumb)                                    \
             -textvariable labelDialogs(onlyThumb)]
-    set noThumbs     [radiobutton $intImages.noThumbs   -value 2    \
-            -variable Opciones::optionsTemp(images)                 \
-            -textvariable labelDialogs(noThumb)]
+    set noThumbs     [underButton::UnderButton $intImages.noThumbs   -value 2  \
+            -variable Opciones::optionsTemp(images) -buttontype radiobutton    \
+            -textvariable labelDialogs(noThumb) -under $indexDialogs(noThumb)]
     
-    set filterFrame  [fl::FrameLabel $intFrame.filters -bd 2 -relief groove        \
+    set filterFrame  [fl::FrameLabel $intFrame.filters -bd 2 -relief groove    \
             -textvariable labelFrames(filters)]
     set intFilters   [frame $filterFrame.int]
-    set mapLinks     [checkbutton $intFilters.mapLinks                             \
-	      -textvariable labelDialogs(getMap)  -variable Opciones::optionsTemp(map) \
-            -command Opciones::ActivateMap]
-    set onlyHtml     [checkbutton $intFilters.onlyHtml \
-            -variable Opciones::optionsTemp(onlyHtml)  \
-            -textvariable labelDialogs(onlyHtml)]
-    set chooseFilter [button $intFilters.choose        \
-            -textvariable labelButtons(chooseFilter)   \
-            -command Opciones::ChangeFilter]
+    set mapLinks     [underButton::UnderButton $intFilters.mapLinks            \
+	        -textvariable labelDialogs(getMap)  -buttontype checkbutton        \
+            -variable Opciones::optionsTemp(map) -under $indexDialogs(map)     \
+            -command Opciones::ActivateMap -under $indexDialogs(getMap)]
+    set onlyHtml     [underButton::UnderButton $intFilters.onlyHtml            \
+            -variable Opciones::optionsTemp(onlyHtml) -buttontype checkbutton  \
+            -under $indexDialogs(onlyHtml) -textvariable labelDialogs(onlyHtml)]
+    set chooseFilter [underButton::UnderButton $intFilters.choose              \
+            -textvariable labelButtons(chooseFilter)   -buttontype button      \
+            -under $indexButtons(chooseFilter) -command Opciones::ChangeFilter]
 
-    set accept  [button $butFrame.accept  -textvariable labelButtons(ok)       \
-		-width 8 -command "Opciones::ChooseOptionsControl"]
-    set cancel  [button $butFrame.cancel -textvariable labelButtons(cancel)    \
-		-width 8 -command "set Opciones::done 0"]
-    set help    [button $butFrame.help    -textvariable  labelButtons(help)    \
-        -width 8 -command "[list help::init [file join $dirGetleft(doc) help.help] howtoDown#Options]"]
-    set saveOps [button $butFrame.save -textvariable labelButtons(save)        \
-        -width 8 -command "Opciones::SaveDefaultOptions"]
-    set loadOps [button $butFrame.load -textvariable labelButtons(load)        \
-        -width 8 -command "
+    set accept  [underButton::UnderButton $butFrame.accept -width 8            \
+        -textvariable labelButtons(ok)     -buttontype button                  \
+        -under $indexButtons(ok)     -command "Opciones::ChooseOptionsControl"]
+    set cancel  [underButton::UnderButton $butFrame.cancel -width 8            \
+        -textvariable labelButtons(cancel)  -buttontype button                 \
+		-under $indexButtons(cancel) -command "set Opciones::done 0"]
+    set help    [underButton::UnderButton $butFrame.help -width 8              \
+        -textvariable  labelButtons(help)   -buttontype button                 \
+        -under $indexButtons(help)                                             \
+        -command "[list help::init [file join $dirGetleft(doc) help.help] howtoDown#Options]"]
+    set saveOps [underButton::UnderButton $butFrame.save -width 8              \
+        -textvariable labelButtons(save)    -buttontype button                 \
+        -under $indexButtons(save)   -command "Opciones::SaveDefaultOptions"]
+    set loadOps [underButton::UnderButton $butFrame.load -width 8              \
+        -textvariable labelButtons(load)    -buttontype button                 \
+        -under $indexButtons(load)                                             \
+        -command "
                 Opciones::SetDefaultOptions Opciones::optionsTemp
                 Opciones::ActivateMap
                 Opciones::UpdateSpinBox internal
@@ -243,8 +256,6 @@ proc ChooseOptionsWindow {parent} {
     set window(onlyHtml)  $onlyHtml
     set window(chooseFil) $chooseFilter
 
-    UpdateSpinBox internal
-    UpdateSpinBox external
     if {$optionsTemp(map)==1} {
         ActivateMap
     }
@@ -357,27 +368,24 @@ proc ChooseOptions {optionsArray {parent .}} {
 
     if {$optionsTemp(levels)==-1} {
         set optionsTemp(limitLevels) 0
+        set optionsTemp(levels) 0
     } else {
         set optionsTemp(limitLevels) 1
     }
     
     ChooseOptionsWindow $parent
+    UpdateSpinBox internal
+    UpdateSpinBox external
     tkwait variable Opciones::done
 
     if {$done==1} {
         array set downOptions [array get optionsTemp]
         if {$optionsTemp(limitLevels)==0} {
             set downOptions(levels) -1
-        } else {
-            set downOptions(levels)   $CuadroSpin::CuadroSpins($window(intSpin))
-        }
-        if {$optionsTemp(external)==0} {
-            set downOptions(exLevels) 0
-        } else {
-            set downOptions(exLevels) $CuadroSpin::CuadroSpins($window(extSpin))
-        }
+        } 
     }
-    catch {destroy $window(win)}
+
+    catch {wm withdraw $window(win)}
 
     return $done
 }
