@@ -7,7 +7,7 @@
 # by executing 'cURL'.
 ##############################################################################
 ##############################################################################
-# Copyright 1999-2002 Andrs Garca Garca  -- fandom@retemail.es
+# Copyright 1999-2003 Andrs Garca Garca  -- fandom@retemail.es
 # Distributed under the terms of the GPL v2
 ##############################################################################
 ##############################################################################
@@ -18,25 +18,34 @@ namespace eval Rizo {
 # Getleft now only works with version 7.9 or newer.
 ##############################################################################
 proc SetCurlVersion {} {
-    global tcl_platform
+    global tcl_platform errorCode
     variable leftIndex
     variable speedIndex
     variable cookieJar
 
-    catch {exec curl -V} curlVersion
-    set version  $curlVersion
+    if {[catch {exec curl -V} curlVersion]} {
+        if {[lindex $errorCode 1]=="ENOENT"} {
+            tk_messageBox -type ok -icon error -title "No curl" \
+                -message "Getleft depends on program\n\tcURL\nPlease check the docs"
+            exit
+        }
+    }
 
-    regexp {([0-9]+)(?:\.)([0-9]+)} $curlVersion nada mayor minor
+    if {![regexp {([0-9]+)(?:\.)([0-9]+)} $curlVersion nada mayor minor]} {
+        tk_messageBox -type ok -icon error -title Error                      \
+                -message "Program cURL doesn't work.\nPlease check the docs."
+        exit
+    }
 
     if {($mayor<7)||($minor<9)} {
         tk_messageBox -title Error -type ok \
                 -message "Your 'cURL' version is too old,\n\
-                          please upgrade $mayor $minor"
+                          please upgrade"
         exit
     }
     set cookieJar [file join $::dirGetleft(conf) cookies.txt]
 
-    # I define this indexes here because they have been known to change
+    # I define these indexes here because they have been known to change
     # with cURL versions.
 
     set leftIndex  10
@@ -47,7 +56,7 @@ proc SetCurlVersion {} {
 
 ##############################################################################
 # Common
-#    This procedure takes care of initializing the state variables an invoke
+#    This procedure takes care of initializing the state variables and invoke
 #    'curl' for all the connection types.
 #
 # Parameters:
@@ -73,7 +82,7 @@ proc Common {type args} {
     set getleftOptions(cancelDown) 0
     set ::errorCode               ""
 
-    set newArgs [concat {-A "Mozilla/4.0 (compatible; Getleft 1.0.5)"} \
+    set newArgs [concat {-A "Mozilla/4.0 (compatible; Getleft 1.1b2)"}        \
                          -b \"$cookieJar\" --connect-timeout 60 [lindex $args 0]]
 
     if {$getleftOptions(proxy)==1} {
@@ -91,9 +100,10 @@ proc Common {type args} {
     } else {
         set curlCmd [concat curl $newArgs]
     }
-    if {$::DEBUG==1} {
-        puts $curlCmd
-    }
+#    if {$::DEBUG==1} {
+#        puts $curlCmd
+#    }
+
     if {$tcl_platform(platform)=="windows"} {
         set curlCmd [concat $curlCmd --stderr -]
         eval {set pipe [open "| $curlCmd" r]}
@@ -125,6 +135,7 @@ proc HeadRequest {link mother} {
     set meta(totalBytes)    -1
 
     regsub -all { } $link {%20} link
+    regexp {(.*)(#)} $link nada link
 
     if {$mother!="-"} {
         set args [list -e $mother -I $link]
@@ -153,6 +164,7 @@ proc DataRequest {file link mother {resume 0}} {
     set curlReport(percentage) 0
 
     regsub -all { } $link {%20} link
+    regexp {(.*)(#)} $link nada link
     if {$mother!="-"} {
         set refererUrl $mother
         set args [list -e $refererUrl -o $file $link]
@@ -177,7 +189,7 @@ proc DataRequest {file link mother {resume 0}} {
 #   something to proccess
 #
 # Parameters:
-#   tipo: type of request (HEAD, GET, ...) or stopNow, to stop
+#   tipo: type of request (HEAD, GET, ...) or 'stopNow' to stop
 ###############################################################################
 proc Lector {tipo} {
     global errorCode getleftState labelDialogs siteUrl tcl_platform
@@ -191,7 +203,6 @@ proc Lector {tipo} {
     variable setCookie
     variable pipe
 
-
     if {($tipo=="stopNow")||($getleftState(downloading)==0)} {
         set pipePid [pid $pipe]
         if {$tcl_platform(platform)=="unix"} {
@@ -220,7 +231,7 @@ proc Lector {tipo} {
 	      if {(($curlError==18)&&($tipo=="cab"))||($curlError=="")} {
                 set curlError 0
             }
-            if {$curlError==7} {
+            if {($curlError==7)||($curlError==6)} {
                 if {![info exists getleftState(noConnect,$siteUrl(www))]} {
                     set getleftState(noConnect,$siteUrl(www)) 0
                 } else {
@@ -230,14 +241,8 @@ proc Lector {tipo} {
         }
         return
     }
-
     if {[gets $pipe line]>=0} {
         if {[string match $line ""]} return
-        if {[lsearch $line "Speed"]!=-1} return
-        if {[regexp {(?:curl: \([0-9]+\) )(.*)} $line nada msg]} {
-            set errorMessage $msg
-            return
-        }
         if {$::DEBUG==1} {
            if {$tipo=="cab"} {
 	            if {![regexp {^\s|^1} $line]} {
@@ -265,10 +270,13 @@ proc Lector {tipo} {
                 Cookies::SaveCookie $line
             }
         } else {
+#regsub -all {\s+} $line { } line
+#puts "Antes:   $line"
+	        if {[regexp {[^0-9kM:\.\s]} $line]!=0} return
+#puts "Despues: $line"
             set curlReport(speed)  [lindex $line $speedIndex]
 
             if {$curlReport(speed)==""} return
-
             set curlReport(percentage) [lindex $line 0]
             if {[regexp {k$} $curlReport(speed)]} {
                 set curlReport(speed) $curlReport(speed)/s
