@@ -5,7 +5,7 @@
 ##### Creates the window which will provide some information to the user 
 ##### while a file is being downloaded.
 ###############################################################################
-##### Copyright 1999-2002 Andrs Garca Garca - fandom@retemail.es
+##### Copyright 1999-2003 Andrs Garca Garca - fandom@retemail.es
 ##### Distributed under the terms of the GPL v2
 ###############################################################################
 
@@ -14,26 +14,72 @@ namespace eval Ventana {
 source [file join $dirGetleft(scripts) Rizo.tcl]
 
 ###############################################################################
-# SetButtonsWidth
-#    Calculates the width the buttons in the downloading window should have
-#    in order to show the complete text.
-#
-# Returns
-#    The width we need.
+# DefineButtonImages
+#    Reads the images needed to create the 'downloading' window.
 ###############################################################################
-proc SetButtonsWidth {} {
-    global   labelButtons
+proc DefineButtonImages {} {
+    global   dirGetleft
+    variable images
 
-    set widthPause  [string length $labelButtons(pause)]
-    set widthSkip   [string length $labelButtons(skip)]
-    set widthResume [string length $labelButtons(resume)]
+    set images(url)    [image create photo                             \
+            -file [file join "$dirGetleft(icons)" html.gif]]
+    set images(folder) [image create photo                             \
+            -file [file join "$dirGetleft(icons)" folder.gif]]
+    set images(files)  [image create photo                             \
+            -file [file join "$dirGetleft(icons)" files.gif]]
+    set images(clock)  [image create photo                             \
+            -file [file join "$dirGetleft(icons)" clock.gif]]
 
-    set buttonWidth [expr {$widthPause >$widthSkip}   ? $widthPause  : $widthSkip]
-    set buttonWidth [expr {$buttonWidth>$widthResume} ? $buttonWidth : $widthResume]
-    set buttonWidth [expr $buttonWidth -1]
-    set buttonWidth [expr {$buttonWidth>8}            ? $buttonWidth : 8]
+    set images(pause)  [image create photo                             \
+            -file  [file join "$dirGetleft(icons)" pauses.gif]]
+    set images(resume) [image create photo                             \
+            -file  [file join "$dirGetleft(icons)" resumes.gif]]
+    set images(stop)   [image create photo                             \
+            -file  [file join "$dirGetleft(icons)" stops.gif]]
+    set images(conf)   [image create photo                             \
+            -file  [file join "$dirGetleft(icons)" confs.gif]]
 
-    return $buttonWidth
+    return
+}
+
+###############################################################################
+# ShowResumeButton
+#    When the user pauses the download, the 'Pause' menu button is 
+#    subtituted by the 'Resume' button
+###############################################################################
+proc ShowResumeButton {} {
+    variable window
+    variable menus
+    global   tcl_platform
+
+    if {$tcl_platform(platform)=="windows"} {
+        set offset -2
+    } else {
+        set offset -3
+    }
+
+    $window(pause) configure -state disabled
+    place $window(resume) -in $window(pause) -x $offset -y $offset
+
+    $menus(stop) entryconfigure 3 -state disabled
+
+    return
+}
+
+###############################################################################
+# HideResumeButton
+#    And when the download is resumed it is hidden again.
+###############################################################################
+proc HideResumeButton {} {
+    variable window
+    variable menus
+
+    place forget $window(resume)
+    $window(pause) configure -state normal
+
+    $menus(stop) entryconfigure 3 -state normal
+
+    return
 }
 
 ###############################################################################
@@ -45,23 +91,21 @@ proc SetButtonsWidth {} {
 ###############################################################################
 proc Pause {which} {
     global getleftOptions labelTitles labelMessages
+    variable window
 
-    set windowState [wm state .bajando]
+    set windowState [wm state $window(top)]
     if {$windowState=="iconic"} {
-        wm deiconify .bajando
+        wm deiconify $window(top)
     }
-    wm withdraw .bajando
-    tk_messageBox -title $labelTitles(paused) -icon info -type ok \
-         -message $labelMessages(paused)
+
+    ShowResumeButton
+#    tk_messageBox -title $labelTitles(paused) -icon info -type ok \
+         -message $labelMessages(paused) -parent $window(top)
     if {$which=="file"} {
         tkwait variable getleftOptions(pauseFile)
     } else {
         tkwait variable getleftOptions(pausePage)
     }
-    wm deiconify .bajando
-    if {$windowState=="iconic"} {
-        wm iconify .bajando
-    }
 
     return
 }
@@ -180,7 +224,7 @@ proc FileStrings {url} {
     global directories labelMessages
     variable window
 
-    set fileName  [::Commands::UrlToFile $url]
+    set fileName  [::Commands::UrlToFile $url $directories(base)]
     set parsedUrl [HtmlParser::ParseUrl $url]
     set domain    [string tolower [lindex $parsedUrl 1]]
 
@@ -213,9 +257,13 @@ proc FileStrings {url} {
 #    displayed.
 ###############################################################################
 proc DownloadWindow {} {
-    global labelButtons labelDialogs
+    global labelButtons labelDialogs labelMenus
     global tcl_platform dirGetleft
     variable window
+    variable menus
+    variable images
+
+    DefineButtonImages
 
     set win [toplevel .bajando]
     wm geometry  $win 290x160
@@ -230,32 +278,23 @@ proc DownloadWindow {} {
     set marco_bar [frame $marco_in.bar]
     set botones   [frame $win.botones]
 
-    set imaUrl    [image create photo \
-            -file [file join "$dirGetleft(images)" html.gif]]
-    set imaFolder [image create photo \
-            -file [file join "$dirGetleft(images)" folder.gif]]
-    set imaFiles  [image create photo \
-            -file [file join "$dirGetleft(images)" files.gif]]
-    set imaClock  [image create photo \
-            -file [file join "$dirGetleft(images)" clock.gif]]
-
-    set etq_url   [label $marco_url.etq_url  -image $imaUrl]
-    set etq_dir   [label $marco_dir.etq_dir  -image $imaFolder]
-    set etq_file  [label $marco_fil.etq_file -image $imaFiles]
-    set etq_que   [label $marco_que.etq_que  -image $imaClock]
+    set etq_url   [label $marco_url.etq_url  -image $images(url)]
+    set etq_dir   [label $marco_dir.etq_dir  -image $images(folder)]
+    set etq_file  [label $marco_fil.etq_file -image $images(files)]
+    set etq_que   [label $marco_que.etq_que  -image $images(clock)]
 
     BalloonHelp::set_balloon $etq_url  $labelDialogs(url)
     BalloonHelp::set_balloon $etq_dir  $labelDialogs(dir)
     BalloonHelp::set_balloon $etq_file $labelDialogs(file)
     BalloonHelp::set_balloon $etq_que  $labelDialogs(left)
 
-    set etq_url2  [label $marco_url.etq_url2  -width 45 -anchor w \
+    set etq_url2  [label $marco_url.etq_url2  -width 45 -anchor w         \
             -bd 2 -relief sunken -textvariable Ventana::window(labelUrl)]
-    set etq_dir2  [label $marco_dir.etq_dir2  -width 45 -anchor w \
+    set etq_dir2  [label $marco_dir.etq_dir2  -width 45 -anchor w         \
             -textvariable Ventana::window(labelDir)]
-    set etq_file2 [label $marco_fil.etq_file2 -width 45 -anchor w \
+    set etq_file2 [label $marco_fil.etq_file2 -width 45 -anchor w         \
             -textvariable Ventana::window(labelFile)]
-    set etq_que2  [label $marco_que.etq_que2  -width 30 -anchor w \
+    set etq_que2  [label $marco_que.etq_que2  -width 30 -anchor w         \
             -textvariable Ventana::Rizo::curlReport(left)]
 
     set progressBar [Progreso::ProgressBar $marco_bar.progress]
@@ -267,14 +306,56 @@ proc DownloadWindow {} {
     set window(left) $etq_que2
     set window(bar)  $progressBar
 
-    set buttonWidth [SetButtonsWidth]
-    set pause    [button $botones.pause    -textvariable labelButtons(pause)\
-        -command ::Ventana::PauseDownloading  -width $buttonWidth]
-    set cancelar [button $botones.cancelar -textvariable labelButtons(skip) \
-        -command "::Ventana::CancelDownloading $Ventana::window(top) skip"  \
-                  -width $buttonWidth]
-    set window(cancel) $cancelar
+    set config   [button $botones.config -width 48 -height 20 -image $images(conf)      \
+            -command "mainWin::UrlListChangeOptions $window(top)"]
+    set pause    [menubutton $botones.pause -menu $botones.pause.menu                   \
+            -width 50 -height 22 -image $images(pause) -relief raised]
+    set stop     [menubutton $botones.stop  -menu $botones.stop.menu                    \
+            -width 50 -height 22 -image $images(stop)  -relief raised]
+    set resume   [button $botones.resume -width 48 -height 20 -image $images(resume)    \
+            -command "::Ventana::ResumeDownloading"]
+
+    ::BalloonHelp::set_balloon $config $labelDialogs(options)
+    ::BalloonHelp::set_balloon $pause  $labelDialogs(pause)
+    ::BalloonHelp::set_balloon $stop   $labelDialogs(stop)
+    ::BalloonHelp::set_balloon $resume $labelDialogs(start)
+
+    set menus(pause) [menu $pause.menu -tearoff 0 -fg black -postcommand "
+            BalloonHelp::kill_balloon
+    "]
+    $menus(pause) add command -label $labelMenus(stopNow) -command {
+            Ventana::PauseDownloading now
+    }
+    $menus(pause) add check -variable getleftOptions(pausePage)              \
+            -onvalue 1 -offvalue 0 -label $labelMenus(stopPage)
+    $menus(pause) add check -variable getleftOptions(pauseFile)              \
+            -onvalue 1 -offvalue 0 -label $labelMenus(stopFile)
+
+    set menus(stop) [menu $stop.menu -tearoff 0 -fg black -postcommand "
+            BalloonHelp::kill_balloon
+    "]
+    $menus(stop) add command -label $labelMenus(stopNow) -command {
+        if {$getleftState(delayedDown)==1} Delay::DelayedCancelDelay
+        ::Ventana::CancelDownloading $Ventana::window(top)
+    }
+    $menus(stop) add check -variable getleftOptions(stopPage)                \
+            -onvalue 1 -offvalue 0 -label $labelMenus(stopPage)              \
+            -command {
+                if {$getleftState(autoDown)==1}    mainWin::SetAutoDownload
+                if {$getleftState(delayedDown)==1} Delay::DelayedCancelDelay
+            }
+    $menus(stop) add check -variable getleftOptions(stopFile)                \
+            -onvalue 1 -offvalue 0 -label $labelMenus(stopFile)              \
+            -command {
+                if {$getleftState(autoDown)==1}    mainWin::SetAutoDownload
+                if {$getleftState(delayedDown)==1} Delay::DelayedCancelDelay
+            }
+    $menus(stop) add command -label $labelButtons(skip)                      \
+            -command "::Ventana::CancelDownloading $Ventana::window(top) skip"
+
+    set window(cancel) $stop
     set window(pause)  $pause
+    set window(resume) $resume
 
     pack $marco     -ipady 5
     pack $botones   -fill both -expand true -side bottom -padx 7
@@ -286,12 +367,10 @@ proc DownloadWindow {} {
     pack $etq_file  $etq_file2 -side left -pady 2 -padx 2
     pack $etq_que   $etq_que2  -side left -pady 2 -padx 2
     pack $progressBar
-    pack $cancelar $pause -side right -padx 3 -pady 5
+    pack $stop $pause $config -side right -padx 3 -pady 5
 
     wm protocol $win WM_DELETE_WINDOW "::Ventana::CancelDownloading $win"
 
-    update
-
     return
 }
 
@@ -306,10 +385,11 @@ proc DownloadWindow {} {
 proc ShowWindow {which} {
     global   labelTitles labelButtons getleftState
     variable window
+    variable action
 
     if {$::getleftState(downloading)==0} {
         if {$::DEBUG==1} {
-            tk_messageBox -title Error -icon error -type ok \
+            tk_messageBox -title Error -icon error -type ok         \
                     -message "Pringamos en ShowWindow: $which"
         }
         return
@@ -318,31 +398,30 @@ proc ShowWindow {which} {
     if {![winfo exists .bajando]} {
         DownloadWindow
     } else {
-        set state [wm state .bajando]
+        set state [wm state $window(top)]
         if {$state=="withdrawn"} {
-            wm deiconify .bajando
+            wm deiconify $window(top)
         }
     }
-    $window(pause) configure -textvariable labelButtons(pause) \
-            -command ::Ventana::PauseDownloading
 
     switch -exact $which {
         head {
-            wm title .bajando $labelTitles(connect)
-            $window(cancel) configure -state normal
+            wm title $window(top) $labelTitles(connect)
         }
         down {
-            wm title .bajando $labelTitles(download)
-            $window(cancel) configure -state normal
+            wm title $window(top) $labelTitles(download)
         }
         process {
-            wm title .bajando $labelTitles(process)
-            $window(cancel) configure -state disabled
+            wm title $window(top) $labelTitles(process)
+            set action process
         }
         wait {
             StartWaiting 10
         }
     }
+
+    update
+
     return
 }
 
@@ -371,8 +450,8 @@ proc FileDownloading {fichero enlace madre} {
     }
 
     set file   $fichero
-    set link   $enlace
-    set mother $madre
+#    set link   $enlace
+#    set mother $madre
     set action body
 
     ShowWindow down
@@ -420,6 +499,18 @@ proc HeadDownloading {enlace madre} {
     ShowWindow head
     FileStrings $enlace
 
+    HideResumeButton
+
+    if {[regexp {^ftp://} $enlace]} {
+        set ::Ventana::Rizo::meta(content)       "nada"
+        set ::Ventana::Rizo::meta(totalBytes)    0
+        set ::Ventana::Rizo::meta(versionServer) 1.1
+        set ::Ventana::Rizo::meta(relocate)      ""
+        set ::Ventana::Rizo::curlError           0
+        set ::Ventana::Rizo::errorMessage        ""
+        return
+    }
+
     set Ventana::Rizo::curlReport(end) 0
     Ventana::Rizo::HeadRequest $enlace $madre
     tkwait variable Ventana::Rizo::curlReport(end)
@@ -429,16 +520,23 @@ proc HeadDownloading {enlace madre} {
 
 ###############################################################################
 # PauseDownloading
-#    Takes control when you click on the 'Pause' button
+#    Takes control when you click on the 'Pause' button.
+#
+# Parameter:
+#    when: 'now' when we click on the 'Now' menu entry, usuful to pause
+#    the downloading while a file is being process for links.
 ###############################################################################
-proc PauseDownloading {} {
-    global labelButtons
+proc PauseDownloading {{when ""}} {
+    global labelButtons getleftOptions
     variable window
 
+    if {$when=="now"} {
+        set getleftOptions(pauseNow) 1
+        set Ventana::Rizo::curlReport(pause) 1
+    }
     set Ventana::Rizo::curlReport(pause) 1
     catch {Rizo::Lector stopNow}
-    $window(pause) configure -textvariable labelButtons(resume) \
-            -command ::Ventana::ResumeDownloading
+    ShowResumeButton
 
     return
 }
@@ -448,16 +546,22 @@ proc PauseDownloading {} {
 #    Takes control when you click on the 'Resume' button
 ###############################################################################
 proc ResumeDownloading {} {
-    global labelButtons
+    global labelButtons getleftOptions
     variable window
     variable file
     variable link
     variable mother
     variable action
 
+    HideResumeButton
+
+    if {($getleftOptions(pauseFile)==1)||($getleftOptions(pausePage)==1)} {
+        set getleftOptions(pauseFile) 0
+        set getleftOptions(pausePage) 0
+        return
+    }
+    set getleftOptions(pauseNow)  0
     set Ventana::Rizo::curlReport(pause) 0
-    $window(pause) configure -textvariable labelButtons(pause) \
-                -command ::Ventana::PauseDownloading
 
     if {$action=="body"} {
         Progreso::ProgressBarReset $window(bar)
@@ -483,14 +587,14 @@ proc StartWaiting {seconds} {
     variable waitingPid
 
     if {$seconds==0} {
-        set getleftState(waiting) 0
+        InterruptWaiting
         return
     }
 
-    wm title .bajando "$labelTitles(waiting) $seconds"
+    wm title $window(top) "$labelTitles(waiting) $seconds"
 
-    $window(pause)  configure -command ::Ventana::InterruptWaiting \
-            -textvariable labelButtons(resume)
+    ShowResumeButton
+    $window(resume) configure -command ::Ventana::InterruptWaiting
 
     set waitingPid [after 1000 ::Ventana::StartWaiting [expr $seconds -1]]
 
@@ -509,6 +613,9 @@ proc InterruptWaiting {} {
 
     after cancel $waitingPid
 
+    HideResumeButton
+    $window(resume) configure -command ::Ventana::ResumeDownloading
+
     set getleftState(waiting) 0
 
     return
@@ -522,7 +629,7 @@ proc BarUpdate {} {
     global Ventana::Rizo::curlReport
     global Ventana::Rizo::curlError
     global Ventana::Rizo::meta
-    global labelDialogs downOptions
+    global labelDialogs downOptions getleftOptions
     variable file
     variable link
     variable mother
@@ -532,37 +639,40 @@ proc BarUpdate {} {
     if {[string match $curlReport(percentage) ""]} return
     Progreso::ProgressBarUpdate $window(bar) $curlReport(percentage)
 
-    if {$curlReport(pause)==0} {
-        if {($curlReport(end)==0) && ($curlReport(stop)!=1)} {
-            set afterId [after 1000 Ventana::BarUpdate]
-        } else {
-            set curlReport(left) ""
-            if {($::DEBUG==1)&&($curlError!=0)} {
-                puts "Error $curlError en $file"
-            }
-            if {($curlError==18)||($curlError==28)} {
-                getLog::FileLogEnter $labelDialogs(fileIncom) \
-                        "$link" "$mother"                        
-                if {($downOptions(resume)==1)&&($curlReport(stop)!=1)} {
-                    Progreso::ProgressBarReset $window(bar)
-                    if {$curlError==18} {
-                        FileDownloading "$file" "$link" "$mother"
-                    } else {
-                        incr curlReport(nextFile)
-                    }
-                    return
-                }
-            }
-            if {$curlError==0} {
-                Progreso::ProgressBarFull $window(bar)
-                update
-            }
-            after 75
-            Progreso::ProgressBarReset $window(bar)
-            $window(dir)  configure -text ""
-            $window(file) configure -text ""
-            incr curlReport(nextFile)
+    if {$getleftOptions(pauseNow)==1} {
+        return
+    }
+
+    if {($curlReport(end)==0) && ($curlReport(stop)!=1) \
+            && ($curlReport(pause)==0)} {
+        set afterId [after 1000 Ventana::BarUpdate]
+    } else {
+        set curlReport(left) ""
+        if {($::DEBUG==1)&&($curlError!=0)} {
+            puts "Error $curlError en $file"
         }
+        if {($curlError==18)||($curlError==28)} {
+            getLog::FileLogEnter $labelDialogs(fileIncom) \
+                    "$link" "$mother"                        
+            if {($downOptions(resume)==1)&&($curlReport(stop)!=1)} {
+                Progreso::ProgressBarReset $window(bar)
+                if {$curlError==18} {
+                    FileDownloading "$file" "$link" "$mother"
+                } else {
+                    incr curlReport(nextFile)
+                }
+                return
+            }
+        }
+        if {$curlError==0} {
+            Progreso::ProgressBarFull $window(bar)
+            update
+        }
+        after 75
+        Progreso::ProgressBarReset $window(bar)
+        $window(dir)  configure -text ""
+        $window(file) configure -text ""
+        incr curlReport(nextFile)
     }
     return
 }
