@@ -6,7 +6,7 @@
 ## This namespace is used to program delayed downloads into Getleft.
 ###############################################################################
 ###############################################################################
-## (c) 2001 Andrs Garca Garca. fandom@retemail.es
+## (c) 2001-2003 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -53,6 +53,7 @@ proc DelayedStartDownload {} {
         DelayedStartTime $delayedDownload(startTime)
     }
     set getleftState(delayedDown) 1
+    mainWin::UrlListClearSel
     mainWin::SetAutoDownload
 
     return
@@ -261,13 +262,14 @@ proc DelayedActivateStop {} {
 ###############################################################################
 proc DelayedDownloadWindow {} {
     global labelDialogs labelTitles labelFrames getleftState getleftOptions
+    global indexButtons indexDialogs
     variable delayedDownloadTemp
     variable dayButton
     variable stopButton
     variable window
 
     if {[winfo exists .delayedDown]} {
-        focus .delayedDown
+        raise .delayedDown .
         return
     }
 
@@ -282,25 +284,26 @@ proc DelayedDownloadWindow {} {
     set extFrame [frame $win.extFrame]
     set intFrame [frame $extFrame.intFrame]
 
-    set timeFrame [fl::FrameLabel $intFrame.time -bd 2 -relief groove  \
+    set timeFrame [fl::FrameLabel $intFrame.time -bd 2 -relief groove           \
             -textvariable labelFrames(time)]
     set startLabel  [label $timeFrame.startLabel -textvariable labelDialogs(begin)]
-    set startHour   [CuadroSpin::CuadroSpin $timeFrame.startHour       \
-            -default 0 -min 0 -max 23 -width 3                         \
+    set startHour   [CuadroSpin::CuadroSpin $timeFrame.startHour                \
+            -default 0 -min 0 -max 23 -width 3                                  \
             -bg $getleftOptions(bg) -fg $getleftOptions(fg)]
-    set startMinute [CuadroSpin::CuadroSpin $timeFrame.startMinute     \
-            -default 0 -min 0 -max 59 -width 3 -incr 5                 \
+    set startMinute [CuadroSpin::CuadroSpin $timeFrame.startMinute              \
+            -default 0 -min 0 -max 59 -width 3 -incr 5                          \
             -bg $getleftOptions(bg) -fg $getleftOptions(fg)]
     set endLabel    [label $timeFrame.endLabel -textvariable labelDialogs(end)]
-    set endHour     [CuadroSpin::CuadroSpin $timeFrame.endHour               \
-            -default 0 -min 0 -max 23 -width 3 -disbg $getleftOptions(disBg) \
-            -bg $getleftOptions(bg) -fg $getleftOptions(fg)                  \
+    set endHour     [CuadroSpin::CuadroSpin $timeFrame.endHour                  \
+            -default 0 -min 0 -max 23 -width 3 -disbg $getleftOptions(disBg)    \
+            -bg $getleftOptions(bg) -fg $getleftOptions(fg)                     \
             -disfg $getleftOptions(disFg)]
-    set endMinute   [CuadroSpin::CuadroSpin $timeFrame.endMinute       \
-            -default 0 -min 0 -max 59 -width 3 -incr 5                 \
-            -disbg $getleftOptions(disBg) -disfg $getleftOptions(disFg)\
+    set endMinute   [CuadroSpin::CuadroSpin $timeFrame.endMinute                \
+            -default 0 -min 0 -max 59 -width 3 -incr 5                          \
+            -disbg $getleftOptions(disBg) -disfg $getleftOptions(disFg)         \
             -bg $getleftOptions(bg) -fg $getleftOptions(fg)]
-    set noEnd [checkbutton $timeFrame.noEnd -textvariable labelDialogs(noLimit) \
+    set noEnd [underButton::UnderButton $timeFrame.noEnd -buttontype checkbutton\
+            -textvariable labelDialogs(noLimit) -under $indexDialogs(noLimit)   \
             -variable Delay::delayedDownloadTemp(noEnd) -command "
                 Delay::DelayedActivateEndTime
                 Delay::DelayedActivateStop
@@ -308,16 +311,16 @@ proc DelayedDownloadWindow {} {
     if {$delayedDownloadTemp(noEnd)==""} {
         set delayedDownloadTemp(noEnd) 1
     }
-    if {[info exists Delay::delayedDownloadTemp(startTime)]} {
+    if {![catch {clock format $delayedDownloadTemp(startTime)}]} {
         set CuadroSpin::CuadroSpins($startHour)   \
                 [clock format $delayedDownloadTemp(startTime) -format "%H"]
         set CuadroSpin::CuadroSpins($startMinute) \
                 [clock format $delayedDownloadTemp(startTime) -format "%M"]
     }
-    if {[info exists Delay::delayedDownloadTemp(endTime)]} {
-        set CuadroSpin::CuadroSpins($endHour)     \
+    if {![catch {clock format $delayedDownloadTemp(endTime)}]} {
+        set CuadroSpin::CuadroSpins($endHour)                                  \
                 [clock format $delayedDownloadTemp(endTime) -format "%H"]
-        set CuadroSpin::CuadroSpins($endMinute)   \
+        set CuadroSpin::CuadroSpins($endMinute)                                \
                 [clock format $delayedDownloadTemp(endTime) -format "%M"]
     }
 
@@ -329,64 +332,83 @@ proc DelayedDownloadWindow {} {
 
     DelayedActivateEndTime
 
-    set howFrame  [fl::FrameLabel $intFrame.how  -bd 2 -relief groove  \
+    set howFrame  [fl::FrameLabel $intFrame.how  -bd 2 -relief groove          \
             -textvariable labelFrames(stop)]
-    set stopButton(inme) [radiobutton $howFrame.inme \
-            -textvariable labelDialogs(inme)               \
-            -variable Delay::delayedDownloadTemp(how) -value 0] 
-    set stopButton(file) [radiobutton $howFrame.file \
-            -textvariable labelDialogs(afterFile)          \
-            -variable Delay::delayedDownloadTemp(how) -value 1]
-    set stopButton(page) [radiobutton $howFrame.page \
-            -textvariable labelDialogs(afterPage)          \
-            -variable Delay::delayedDownloadTemp(how) -value 2]
+    set stopButton(inme) [underButton::UnderButton $howFrame.inme              \
+            -textvariable labelDialogs(inme)      -buttontype radiobutton      \
+            -variable Delay::delayedDownloadTemp(how) -value 0                 \
+            -under $indexDialogs(inme)] 
+    set stopButton(file) [underButton::UnderButton $howFrame.file              \
+            -textvariable labelDialogs(afterFile) -buttontype radiobutton      \
+            -variable Delay::delayedDownloadTemp(how) -value 1                 \
+            -under $indexDialogs(afterFile)]
+    set stopButton(page) [underButton::UnderButton $howFrame.page              \
+            -textvariable labelDialogs(afterPage) -buttontype radiobutton      \
+            -variable Delay::delayedDownloadTemp(how) -value 2                 \
+            -under $indexDialogs(afterPage)]
     if {$delayedDownloadTemp(how)==""} {
         set delayedDownloadTemp(how) 1
     }
     DelayedActivateStop
 
-    set daysFrame [fl::FrameLabel $intFrame.days -bd 2 -relief groove             \
+    set daysFrame [fl::FrameLabel $intFrame.days -bd 2 -relief groove          \
             -textvariable labelFrames(days)]
-    set today [radiobutton $daysFrame.today -textvariable labelDialogs(onlyToday) \
-            -variable Delay::delayedDownloadTemp(days) -value 0                   \
+    set today [underButton::UnderButton $daysFrame.today -buttontype radiobutton\
+            -textvariable labelDialogs(onlyToday)                              \
+            -variable Delay::delayedDownloadTemp(days) -value 0                \
+            -buttontype radiobutton -under $indexDialogs(onlyToday)            \
             -command Delay::DelayedActivateDays]
-    set on    [radiobutton $daysFrame.on    -textvariable labelDialogs(on)        \
-            -variable Delay::delayedDownloadTemp(days) -value 1                   \
+    set on    [underButton::UnderButton $daysFrame.on -buttontype radiobutton  \
+            -textvariable labelDialogs(on) -under $indexDialogs(on)            \
+            -variable Delay::delayedDownloadTemp(days) -value 1                \
             -command Delay::DelayedActivateDays]
     if {$delayedDownloadTemp(days)==""} {
         set delayedDownloadTemp(days) 0
     }
 
-    set dayButton(monday)    [checkbutton $daysFrame.monday    \
-            -textvariable labelDialogs(monday)                 \
-            -variable Delay::delayedDownloadTemp(monday)]
-    set dayButton(tuesday)   [checkbutton $daysFrame.tuesday   \
-            -textvariable labelDialogs(tuesday)                \
-            -variable Delay::delayedDownloadTemp(tuesday)]
-    set dayButton(wednesday) [checkbutton $daysFrame.wednesday \
-            -textvariable labelDialogs(wednesday)              \
-            -variable Delay::delayedDownloadTemp(wednesday)]
-    set dayButton(thursday)  [checkbutton $daysFrame.thursday  \
-            -textvariable labelDialogs(thursday)               \
-            -variable Delay::delayedDownloadTemp(thursday)]
-    set dayButton(friday)    [checkbutton $daysFrame.friday    \
-            -textvariable labelDialogs(friday)                 \
-            -variable Delay::delayedDownloadTemp(friday)]
-    set dayButton(saturday)  [checkbutton $daysFrame.saturday  \
-            -textvariable labelDialogs(saturday)               \
-            -variable Delay::delayedDownloadTemp(saturday)]
-    set dayButton(sunday)    [checkbutton $daysFrame.sunday    \
-            -textvariable labelDialogs(sunday)                 \
-            -variable Delay::delayedDownloadTemp(sunday)]
+    set dayButton(monday)    [underButton::UnderButton $daysFrame.monday       \
+            -textvariable labelDialogs(monday)    -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(monday)                       \
+            -under $indexDialogs(monday)]
+    set dayButton(tuesday)   [underButton::UnderButton $daysFrame.tuesday      \
+            -textvariable labelDialogs(tuesday)   -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(tuesday)                      \
+            -under $indexDialogs(tuesday)]
+    set dayButton(wednesday) [underButton::UnderButton $daysFrame.wednesday    \
+            -textvariable labelDialogs(wednesday) -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(wednesday)                    \
+            -under $indexDialogs(wednesday)]
+    set dayButton(thursday)  [underButton::UnderButton $daysFrame.thursday     \
+            -textvariable labelDialogs(thursday)  -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(thursday)                     \
+            -under $indexDialogs(thursday)]
+    set dayButton(friday)    [underButton::UnderButton $daysFrame.friday       \
+            -textvariable labelDialogs(friday)    -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(friday)                       \
+            -under $indexDialogs(friday)]
+    set dayButton(saturday)  [underButton::UnderButton $daysFrame.saturday     \
+            -textvariable labelDialogs(saturday)  -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(saturday)                     \
+            -under $indexDialogs(saturday)]
+    set dayButton(sunday)    [underButton::UnderButton $daysFrame.sunday       \
+            -textvariable labelDialogs(sunday)    -buttontype checkbutton      \
+            -variable Delay::delayedDownloadTemp(sunday)                       \
+            -under $indexDialogs(sunday)]
     DelayedActivateDays
 
     set buttonFrame [frame $win.buttonFrame]
-    set accept [button $buttonFrame.accept -textvariable labelButtons(ok)      \
-        -width 8 -command "Delay::DelayedDownloadControl 1"]
-    set cancel [button $buttonFrame.cancel -textvariable labelButtons(cancel)  \
-        -width 8 -command "Delay::DelayedDownloadControl 0"]
-    set clear  [button $buttonFrame.clear -textvariable labelButtons(clear)    \
-        -width 8 -command "Delay::DelayedDownloadControl 2"]
+    set accept [underButton::UnderButton $buttonFrame.accept                   \
+        -buttontype button -textvariable labelButtons(ok)                      \
+        -width 8 -command "Delay::DelayedDownloadControl 1"                    \
+        -under $indexButtons(ok)]
+    set cancel [underButton::UnderButton $buttonFrame.cancel                   \
+        -buttontype button -textvariable labelButtons(cancel)                  \
+        -width 8 -command "Delay::DelayedDownloadControl 0"                    \
+        -under $indexButtons(cancel)]
+    set clear  [underButton::UnderButton $buttonFrame.clear                    \
+        -buttontype button -textvariable labelButtons(clear)                   \
+        -width 8 -command "Delay::DelayedDownloadControl 2"                    \
+        -under $indexButtons(clear)]
 
     pack $extFrame -padx 5
     pack $intFrame 
@@ -439,7 +461,7 @@ proc DelayedDownloadControl {done} {
         set startMinute $CuadroSpin::CuadroSpins($window(startMinute))
 
         if {[DelayedCheckTime $startHour $startMinute]==1} {
-            tk_messageBox -title $labelTitles(error) -parent $window(win) \
+            tk_messageBox -title $labelTitles(error) -parent $window(win)     \
                     -message $labelMessages(wrongStart)     -type ok 
             return
         }
@@ -458,7 +480,7 @@ proc DelayedDownloadControl {done} {
                  &&($delayedDownloadTemp(wednesday)==0)&&($delayedDownloadTemp(thursday)==0)\
                  &&($delayedDownloadTemp(friday)==0)   &&($delayedDownloadTemp(saturday)==0)\
                  &&($delayedDownloadTemp(sunday)==0)} {
-                tk_messageBox -title $labelTitles(error)   -parent $window(win)   \
+                tk_messageBox -title $labelTitles(error)   -parent $window(win)             \
                         -message $labelMessages(whichDays) -type ok 
                 return
             }
@@ -482,7 +504,7 @@ proc DelayedDownloadControl {done} {
     }
     DelayedStartTime $startTime
     if {$delayedDownload(noEnd)==0} {
-        set delayedDownload(endTime) \
+        set delayedDownload(endTime)         \
                 [DelayedEndTime $endHour $endMinute $delayedDownload(startTime)]
     }
 
