@@ -1,15 +1,15 @@
-###############################################################################
-###############################################################################
+################################################################################
+################################################################################
 ##                             getLog.tcl
-###############################################################################
-###############################################################################
-## Defines the Getleft's log window.
-###############################################################################
-###############################################################################
-## (c) 2001-2002 Andrs Garca Garca. fandom@retemail.es
+################################################################################
+################################################################################
+## Defines Getleft's log windows.
+################################################################################
+################################################################################
+## (c) 2001-2003 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the GPL v2
-###############################################################################
-###############################################################################
+################################################################################
+################################################################################
 
 namespace eval getLog {
 
@@ -50,16 +50,16 @@ proc DefineTaskbarButtons {frame} {
     ::BalloonHelp::set_balloon $siteTaskbar(conf)   $labelDialogs(options)
 
     set siteTaskbar(exit) [button $frame.exit  -image $iconNS::iconImages(exit) \
-            -relief flat -bd 1 -command "destroy $siteLog(toplevel)"]
+            -relief flat -bd 1 -command "wm withdraw $siteLog(toplevel)"]
     ::BalloonHelp::set_balloon $siteTaskbar(exit)   $labelDialogs(exit)
 
     foreach {name path} [array get siteTaskbar] {
         bindtags $path "[bindtags $path] logTaskIcon"
     }
-    bind logTaskIcon <Enter> {
+    bind logTaskIcon <<ButtonRaise>> {
         %W configure -relief raised
     }
-    bind logTaskIcon <Leave> {
+    bind logTaskIcon <<ButtonFlat>> {
         %W configure -relief flat
     }
 
@@ -103,7 +103,6 @@ proc UrlLogWrite {} {
     variable urlLog
     global dirGetleft tcl_platform
 
-
     set urlLogFile [file join $dirGetleft(conf) getLog.log]
     if {(![info exists urlLog(urlList)])||([llength $urlLog(urlList)]==0)} {
         catch {file delete $urlLogFile}
@@ -126,11 +125,14 @@ proc UrlLogWrite {} {
     puts $handle "set urlLog(urlList) [list $urlLog(urlList)]"
     puts $handle "\n\n"
     foreach url $urlLog(urlList) {
-        puts $handle "set urlLog($url,localDir) \"$urlLog($url,localDir)\""
-        puts $handle "set urlLog($url,date)     $urlLog($url,date)"
-        puts $handle "set urlLog($url,options)  [list $urlLog($url,options)]"
-        puts $handle "set urlLog($url,keep)     $urlLog($url,keep)"
-#       puts $handle "set urlLog($url,encoding) $urlLog($url,encoding)"
+        regsub -all {\s} $url {\\&} urlTmp
+        catch {
+            puts $handle "set urlLog($urlTmp,localDir) \"$urlLog($url,localDir)\""
+            puts $handle "set urlLog($urlTmp,date)     $urlLog($url,date)"
+            puts $handle "set urlLog($urlTmp,options)  [list $urlLog($url,options)]"
+            puts $handle "set urlLog($urlTmp,keep)     $urlLog($url,keep)"
+#           puts $handle "set urlLog($urlTmp,encoding) $urlLog($url,encoding)"
+        }
     }
     puts $handle "\n\n"
     close $handle
@@ -251,7 +253,7 @@ proc UrlLogEnter {url dir options} {
         if {$urlNumber>=100} {
             for {set i 0} {$i<$urlNumber} {incr i} {
                 set urlTmp [lindex $urlLog(urlList) $i]
-                if {$urlLog($urlTmp,keep)==0} {
+                if {(![info exists urlLog($urlTmp,keep)])||($urlLog($urlTmp,keep)==0)} {
                     UrlLogRemove $urlTmp
                     break
                 }
@@ -407,6 +409,40 @@ proc UrlLogChangeDir {url} {
     return
 }
 
+################################################################################
+# UrlLogLaunchLocalCopy
+#    If the local copy of the site is still present, this will launch the 
+#    browser and open it. 
+#
+# Parameters
+#    url: The downloaded url.
+#    dir: The directory in which the site was saved.
+################################################################################
+proc UrlLogLaunchLocalCopy {url dir} {
+    global labelTitles labelMessages
+    variable siteLog
+
+    set localFile [Commands::UrlToFile $url $dir]
+
+    if {![file exists $localFile]} {
+        tk_messageBox -type ok -icon error -message $labelMessages(noFile) \
+                -title $labelTitles(error) -parent $siteLog(toplevel)
+        return
+    }
+    if {[file isdirectory $localFile]} {
+        set tmpFileI  [file join $localFile index.html]
+        set tmpFileII [file join $localFile index.htm]
+        if {[file exists $tmpFileI]} {
+            set localFile $tmpFileI
+        } elseif {[file exists $tmpFileII]} {
+            set localFile $tmpFileII
+        }
+    }
+    Ayuda::InvokeBrowser $localFile $getLog::siteLog(toplevel)
+
+    return
+}
+
 ################################################################################
 # UrlLogRemove
 #    Removes one Url from the log 
@@ -454,7 +490,6 @@ proc UrlLogRightClick {win x y X Y} {
     variable siteLog
     variable siteMenus
     variable urlLog
-    global getleftState
 
     set index [UrlLogGetIndex $win $y]
     if {$index==-1} return
@@ -462,21 +497,29 @@ proc UrlLogRightClick {win x y X Y} {
     ActivateSiteTaskbarButtons
 
     set url [$siteLog(listbox) cellcget $index,0 -text]
+    set dir [$siteLog(listbox) cellcget $index,1 -text]
 
-    $siteMenus(rightClick) entryconfigure 0 -command "getLog::UrlLogDownload $url"
-    $siteMenus(rightClick) entryconfigure 1 -command "getLog::UrlLogUpdate   $url"
-    $siteMenus(rightClick) entryconfigure 3 -command "getLog::UrlLogQueue    $url"
-    $siteMenus(rightClick) entryconfigure 5 \
-            -command "getLog::UrlLogChangeOptions $url"
-    $siteMenus(rightClick) entryconfigure 6 \
-            -command "getLog::UrlLogChangeDir $url"
-    $siteMenus(rightClick) entryconfigure 7 \
+    $siteMenus(rightClick) entryconfigure 0                                  \
+            -command "getLog::UrlLogDownload [list $url]"
+    $siteMenus(rightClick) entryconfigure 1                                  \
+            -command "getLog::UrlLogUpdate   [list $url]"
+    $siteMenus(rightClick) entryconfigure 3                                  \
+            -command "getLog::UrlLogQueue    [list $url]"
+    $siteMenus(rightClick) entryconfigure 5                                  \
+            -command "getLog::UrlLogChangeOptions [list $url]"
+    $siteMenus(rightClick) entryconfigure 6                                  \
+            -command "getLog::UrlLogChangeDir [list $url]"
+    $siteMenus(rightClick) entryconfigure 7                                  \
             -variable getLog::urlLog($url,keep)
-    $siteMenus(rightClick) entryconfigure 9 \
+    $siteMenus(rightClick) entryconfigure 9                                  \
             -command "clipboard clear
-                      clipboard append $url"
-    $siteMenus(rightClick) entryconfigure 11 \
-            -command "getLog::UrlLogRemove $url"
+                      clipboard append [list $url]"
+    $siteMenus(rightClick) entryconfigure 11                                 \
+            -command "Ayuda::InvokeBrowser $url $getLog::siteLog(toplevel)"
+    $siteMenus(rightClick) entryconfigure 12                                 \
+            -command "getLog::UrlLogLaunchLocalCopy [list $url] [list $dir]"
+    $siteMenus(rightClick) entryconfigure 14                                 \
+            -command "getLog::UrlLogRemove [list $url]"
 
     tk_popup $siteMenus(rightClick) $X $Y
 
@@ -498,7 +541,6 @@ proc UrlLogDoubleClick {win x y X Y} {
     variable siteLog
     variable siteMenus
     variable urlLog
-    global getleftState
 
     set index [UrlLogGetIndex $win $y]
     if {$index==-1} return
@@ -507,8 +549,10 @@ proc UrlLogDoubleClick {win x y X Y} {
 
     set url [$siteLog(listbox) cellcget $index,0 -text]
 
-    $siteMenus(doubleClick) entryconfigure 0 -command "getLog::UrlLogDownload $url"
-    $siteMenus(doubleClick) entryconfigure 1 -command "getLog::UrlLogUpdate   $url"
+    $siteMenus(doubleClick) entryconfigure 0                         \
+            -command "getLog::UrlLogDownload [list $url]"
+    $siteMenus(doubleClick) entryconfigure 1                         \
+            -command "getLog::UrlLogUpdate   [list $url]"
 
     tk_popup $siteMenus(doubleClick) $X $Y
 
@@ -611,6 +655,8 @@ proc GetLogCanonicalSize {size} {
         set size [expr $size * 1024]
     } elseif {[regexp {(.*)(M)} $size nada size]} {
         set size [expr $size * 1024 * 1024]
+    } else {
+        regexp {(.*)(B)} $size nada size
     }
 
     return $size
@@ -676,7 +722,7 @@ proc GetLogWindowPopulate {} {
     variable siteLog
 
     foreach url $urlLog(urlList) {
-        GetLogWindowRow $url $urlLog($url,localDir)
+        catch {GetLogWindowRow $url $urlLog($url,localDir)}
     }
     $siteLog(listbox) yview  0
     return
@@ -692,7 +738,12 @@ proc GetLogWindow {} {
     variable siteMenus
 
     if {[winfo exists .getLogWindow]} {
-        focus $siteLog(toplevel)
+        set windowState [wm state .getLogWindow]
+        if {$windowState=="withdrawn"} {
+            wm deiconify .getLogWindow
+        }
+        raise $siteLog(toplevel) .
+        focus $siteLog(listbox)
         return
     }
 
@@ -723,7 +774,7 @@ proc GetLogWindow {} {
 	        -showarrow 1 -labelcommand tablelist::sortByColumn  \
             -xscrollcommand "$scrollbarX set"                   \
             -yscrollcommand "$scrollbarY set"                   \
-            -stripebg #eff9fa]
+            -stripebg #eff9fa -exportselection 0]
 
     $listbox columnconfigure 0 -sortmode command
     $listbox columnconfigure 0 -sortcommand ::getLog::GetLogSortUrl
@@ -743,7 +794,7 @@ proc GetLogWindow {} {
     pack $logFrame -expand true -fill both
     grid $scrollbarY -in $logFrame -row 0 -column 1 -sticky ns
     grid $scrollbarX -in $logFrame -row 1 -column 0 -sticky ew
-    grid $listbox       -in $logFrame -row 0 -column 0 -sticky news \
+    grid $listbox    -in $logFrame -row 0 -column 0 -sticky news \
             -padx 0 -pady 0
 
     grid columnconfigure $logFrame 0 -weight 1
@@ -753,20 +804,37 @@ proc GetLogWindow {} {
 
     focus [$listbox bodypath]
 
-    bind [$listbox bodypath] <ButtonRelease-1> {
+    bind [$listbox bodypath] <ButtonRelease-1> "
         getLog::ActivateSiteTaskbarButtons
-    }
+        focus [$listbox bodypath]
+    "
     bind [$listbox bodypath] <Button-3> {
+        event generate %W <Button-1>        -x %x -y %y
+        event generate %W <ButtonRelease-1> -x %x -y %y
         getLog::UrlLogRightClick %W %x %y %X %Y
     }
     bind [$listbox bodypath] <Double-Button-1> {
         getLog::UrlLogDoubleClick %W %x %y %X %Y
     }
+    bind [$listbox bodypath] <FocusIn> {
+        $getLog::siteLog(listbox) selection set active
+        ActivateSiteTaskbarButtons
+    }
+    bind [$listbox bodypath] <FocusIn> {
+        $getLog::siteLog(listbox) selection clear 0 end
+        $getLog::siteLog(listbox) selection set active
+    }
+    bind [$listbox bodypath] <KeyRelease-Next> {
+        $getLog::siteLog(listbox) selection clear 0 end
+        $getLog::siteLog(listbox) selection set active
+    }
+    bind [$listbox bodypath] <KeyRelease-Prior> {
+        $getLog::siteLog(listbox) selection clear 0 end
+        $getLog::siteLog(listbox) selection set active
+    }
     bind $win <Key-Delete> {
-        set getLog::tmpUrl   [getLog::UrlLogSelectedUrl]
-        set getLog::tmpIndex [getLog::UrlLogUrlIndex $getLog::tmpUrl]
-        getLog::UrlLogRemove $getLog::tmpUrl
-        $getLog::siteLog(listbox) selection set $getLog::tmpIndex
+        getLog::UrlLogRemove [getLog::UrlLogSelectedUrl]
+        $getLog::siteLog(listbox) selection set active
     }
     bind $win <Escape>     "destroy $win"
 
@@ -782,13 +850,16 @@ proc GetLogWindow {} {
     $siteMenus(rightClick) add separator
     $siteMenus(rightClick) add command -label $labelDialogs(copyLink)
     $siteMenus(rightClick) add separator
+    $siteMenus(rightClick) add command -label $labelDialogs(launchLink)
+    $siteMenus(rightClick) add command -label $labelDialogs(seeDown)
+    $siteMenus(rightClick) add separator
     $siteMenus(rightClick) add command -label $labelMenus(delete)
 
     set siteMenus(doubleClick) [menu $win.menud -tearoff 0]
     $siteMenus(doubleClick) add command -label $labelMenus(download)
     $siteMenus(doubleClick) add command -label $labelMenus(update)
 
-    ActivateSiteTaskbarButtons
+    GetLogWindowPopulate
 
     return
 }
@@ -807,7 +878,6 @@ proc GetLog {} {
     }
 
     GetLogWindow
-    GetLogWindowPopulate
 
     return
 }
@@ -843,6 +913,65 @@ proc ActivateFileTaskbarButtons {} {
 
     return
 }
+
+################################################################################
+# FileLogRemove
+#    Removes one Url from the log 
+#
+# Parameters
+#    url: The url to remove.
+################################################################################
+proc FileLogRemove {} {
+    variable fileLog
+
+    set anchor [$fileLog(listbox) curselection]
+    if {$anchor==""} return
+
+    $fileLog(listbox) delete $anchor
+    $fileLog(listbox) selection set $anchor
+    ActivateFileTaskbarButtons
+
+    return
+}
+
+################################################################################
+# FileLogRightClick
+#   This procedure is invoked when the user right-clicks in the multicolumn
+#   list with the files, it makes a context menu pop up with the
+#   appropiate options
+#
+# Parameters
+#   win: window where you right-clicked.
+#   y,x: the coordinates where you did it for the tablelist widget.
+#   X,Y: and for the pop up menu.
+################################################################################
+proc FileLogRightClick {win x y X Y} {
+    variable fileLog
+    variable fileMenus
+
+    set url [FileLogSelectedUrl]
+    if {$url==""} return
+    set ref [FileLogSelectedRef]
+
+    ActivateFileTaskbarButtons
+
+    $fileMenus(rightClick) entryconfigure 0                                  \
+            -command "getLog::FileLogDownload [list $url]"
+    $fileMenus(rightClick) entryconfigure 2                                  \
+            -command "clipboard clear
+                      clipboard append [list $url]"
+    $fileMenus(rightClick) entryconfigure 4                                  \
+            -command "Ayuda::InvokeBrowser [list $url] $getLog::fileLog(win)"
+    $fileMenus(rightClick) entryconfigure 5                                  \
+            -command "Ayuda::InvokeBrowser [list $ref] $getLog::fileLog(win)"
+    $fileMenus(rightClick) entryconfigure 7                                  \
+            -command "getLog::FileLogRemove"
+
+    tk_popup $fileMenus(rightClick) $X $Y
+
+    return
+}
+
 ################################################################################
 # FileLogSelectedUrl
 #   When the user clicks on the icons, this procedure is used to know the url
@@ -861,17 +990,37 @@ proc FileLogSelectedUrl {} {
     return $url
 }
 
+################################################################################
+# FileLogSelectedRef
+#   When the user clicks on the icons, this procedure is used to know the 
+#   referrer of the url of the row that was selected at the time.
+#
+# Returns
+#   The referrer or an empty string if no row is selected
+################################################################################
+proc FileLogSelectedRef {} {
+    variable fileLog
+
+    set anchor [$fileLog(listbox) curselection]
+    if {[catch {$fileLog(listbox) cellcget $anchor,3 -text} ref]} {
+        return
+    }
+    if {$ref!="-"} {
+        return $ref
+    }
+    return        
+}
+
 ################################################################################
 # FileLogDownload
 #   Ask for a directory and starts downloading the given url.
 ################################################################################
 proc FileLogDownload {url} {
-    global getleftState dirGetleft
     variable fileLog
 
     if {$url==""} return
 
-    EnterUrl::EnterUrl 0 $fileLog(win) $url
+    EnterUrl::EnterUrl 0 $fileLog(win) $url 
 
     return
 }
@@ -899,16 +1048,16 @@ proc FileLogDefineTaskbarButtons {frame} {
     ::BalloonHelp::set_balloon $fileTaskbar(clear)  $labelButtons(clear)
 
     set fileTaskbar(exit) [button $frame.exit    -image $iconNS::iconImages(exit) \
-            -relief flat -bd 1 -command "destroy $fileLog(win)"]
+            -relief flat -bd 1 -command "wm withdraw $fileLog(win)"]
     ::BalloonHelp::set_balloon $fileTaskbar(exit)   $labelDialogs(exit)
 
     foreach {name path} [array get fileTaskbar] {
         bindtags $path "[bindtags $path] logTaskIcon"
     }
-    bind logTaskIcon <Enter> {
+    bind logTaskIcon <<ButtonRaise>> {
         %W configure -relief raised
     }
-    bind logTaskIcon <Leave> {
+    bind logTaskIcon <<ButtonFlat>> {
         %W configure -relief flat
     }
     pack $fileTaskbar(start) $fileTaskbar(clear) -side left
@@ -1040,12 +1189,18 @@ proc FileLogScroll {text how} {
 #   Shows a window with  the contents of the file log.
 ###############################################################################
 proc FileLog {} {
-    global labelButtons labelTitles labelMessages labelDialogs
+    global labelButtons labelTitles labelMessages labelDialogs labelMenus
     global dirGetleft supportedLang getleftOptions
     variable fileLog
+    variable fileMenus
 
     if {[winfo exists .fileLog]} {
-        focus .fileLog
+        set windowState [wm state .fileLog]
+        if {$windowState=="withdrawn"} {
+            wm deiconify .fileLog
+        }
+        raise $fileLog(win)
+        focus $fileLog(listbox)
         return
     }
 
@@ -1065,23 +1220,23 @@ proc FileLog {} {
     set taskBarFrame [frame $intFrame.taskBar]
     set logFrame     [frame $intFrame.log -bd 2 -relief sunken]
 
-    set scrollBars(y) [scrollbar $intFrame.yscroll -orient vertical   \
+    set scrollBars(y) [scrollbar $intFrame.yscroll -orient vertical     \
             -command [list $logFrame.listbox yview] ]
-    set scrollBars(x) [scrollbar $intFrame.xscroll -orient horizontal \
+    set scrollBars(x) [scrollbar $intFrame.xscroll -orient horizontal   \
             -command [list $logFrame.listbox xview] ]
 
-    set fileLog(listbox) [::tablelist::tablelist $logFrame.listbox \
-            -bd 0 -height 10 -width 120 -stretch all                \
-            -fg $getleftOptions(fg) -bg $getleftOptions(bg)         \
-            -columns [list 0 $labelDialogs(code)     left           \
-                           0 $labelDialogs(url)      left           \
-                           0 $labelDialogs(size)     right          \
-                           0 $labelDialogs(referer)  left           \
-                           0 $labelDialogs(date)     left]          \
-            -showarrow 1 -labelcommand tablelist::sortByColumn      \
-            -xscrollcommand "$scrollBars(x) set"                    \
-            -yscrollcommand "$scrollBars(y) set"                    \
-            -stripebg #eff9fa]
+    set fileLog(listbox) [::tablelist::tablelist $logFrame.listbox      \
+            -bd 0 -height 10 -width 120 -stretch all                    \
+            -fg $getleftOptions(fg) -bg $getleftOptions(bg)             \
+            -columns [list 0 $labelDialogs(code)     left               \
+                           0 $labelDialogs(url)      left               \
+                           0 $labelDialogs(size)     right              \
+                           0 $labelDialogs(referer)  left               \
+                           0 $labelDialogs(date)     left]              \
+            -showarrow 1 -labelcommand tablelist::sortByColumn          \
+            -xscrollcommand "$scrollBars(x) set"                        \
+            -yscrollcommand "$scrollBars(y) set"                        \
+            -stripebg #eff9fa -exportselection 0]
 
     $fileLog(listbox) columnconfigure 0 -labelalign center
     $fileLog(listbox) columnconfigure 2 -labelalign center
@@ -1104,7 +1259,7 @@ proc FileLog {} {
 
     grid $scrollBars(y)     -in $logFrame -row 0 -column 1 -sticky ns
     grid $scrollBars(x)     -in $logFrame -row 1 -column 0 -sticky ew
-    grid $fileLog(listbox) -in $logFrame -row 0 -column 0 -sticky news \
+    grid $fileLog(listbox)  -in $logFrame -row 0 -column 0 -sticky news \
             -padx 0 -pady 0
 
     grid columnconfigure $logFrame 0 -weight 1
@@ -1114,15 +1269,36 @@ proc FileLog {} {
 
     bind $fileLog(win) <Escape> "destroy $fileLog(win)"
 
-    bind [$fileLog(listbox) bodypath] <ButtonRelease-1> {
+    bind [$fileLog(listbox) bodypath] <ButtonRelease-1> "
         getLog::ActivateFileTaskbarButtons
-    }
+        focus [$fileLog(listbox) bodypath]
+    "
     bind [$fileLog(listbox) bodypath] <Double-Button-1> {
         getLog::FileLogDownload [getLog::FileLogSelectedUrl]
     }
-
-    focus $fileLog(listbox)
-    ActivateFileTaskbarButtons
+    bind [$fileLog(listbox) bodypath] <Button-3> {
+        event generate %W <Button-1>        -x %x -y %y
+        event generate %W <ButtonRelease-1> -x %x -y %y
+        getLog::FileLogRightClick %W %x %y %X %Y
+    }
+    bind [$fileLog(listbox) bodypath] <Key-Delete> {
+        getLog::FileLogRemove
+        $getLog::fileLog(listbox) selection set active
+    }
+    bind [$fileLog(listbox) bodypath] <FocusIn> {
+        $getLog::fileLog(listbox) selection clear 0 end
+        $getLog::fileLog(listbox) selection set active
+        getLog::ActivateFileTaskbarButtons
+    }
+    bind [$fileLog(listbox) bodypath] <KeyRelease-Next> {
+        $getLog::fileLog(listbox) selection clear 0 end
+        $getLog::fileLog(listbox) selection set active
+    }
+    bind [$fileLog(listbox) bodypath] <KeyRelease-Prior> {
+        $getLog::fileLog(listbox) selection clear 0 end
+        $getLog::fileLog(listbox) selection set active
+    }
+    focus [$fileLog(listbox) bodypath]
 
     if {![file exists $fileLog(file)]} {
         return
@@ -1133,12 +1309,23 @@ proc FileLog {} {
     fconfigure $handle -encoding $supportedLang($getleftOptions(lang))
 
     for {} {![eof $handle]} {} {
-        set linea [gets $handle]
-        if {$linea!=""} {
-            $fileLog(listbox) insert end $linea
+        set line [gets $handle]
+        if {$line!=""} {
+            catch {$fileLog(listbox) insert end $line}
         }
     }
 
+    set fileMenus(rightClick) [menu $fileLog(win).menur -tearoff 0]
+    $fileMenus(rightClick) add command -label $labelMenus(download)
+    $fileMenus(rightClick) add separator
+    $fileMenus(rightClick) add command -label $labelDialogs(copyLink)
+    $fileMenus(rightClick) add separator
+    $fileMenus(rightClick) add command -label $labelDialogs(launchLink)
+    $fileMenus(rightClick) add command -label $labelDialogs(launchRef)
+    $fileMenus(rightClick) add separator
+    $fileMenus(rightClick) add command -label $labelMenus(delete)        \
+            -command "getLog::FileLogRemove"
+
     close $handle
     ActivateFileTaskbarButtons
 
