@@ -6,13 +6,22 @@
 ## Creates an entry widget with right-click context menu.
 ###############################################################################
 ###############################################################################
-## (c) 2002 Andrs Garca Garca. fandom@retemail.es
+## (c) 2002-2003 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the LGPL v2
 ###############################################################################
 ###############################################################################
 
 namespace eval menuEntry {
 
+# One of my ugly kludges
+if {![info exists labelMenus(cut)]} {
+    set ::labelMenus(cut)        Cut
+    set ::labelMenus(copy)       Copy
+    set ::labelMenus(paste)      Paste
+    set ::labelMenus(clear)      Clear
+    set ::labelMenus(selectAll) "Select all"
+}
+
 ###############################################################################
 # ReadSel
 #    Reads the selection from the clipboard
@@ -39,10 +48,10 @@ proc ReadSel {} {
 #
 # Parameters:
 #    menu: Path of the menu.
-#    entry: Path of the entry
+#    entryPath: Path of the entry
 #    X-Y: Coordinates where the menu should appear.
 ###############################################################################
-proc PopUpMenu {menu entry X Y} {
+proc PopUpMenu {menu entryPath X Y} {
 
     set sel [ReadSel]
     if {$sel==""} {
@@ -50,7 +59,8 @@ proc PopUpMenu {menu entry X Y} {
     } else {
         $menu entryconfigure 2 -state normal
     }
-    if {[$entry select present]} {
+    set sel [$entryPath selection present]
+    if {$sel==1} {
         $menu entryconfigure 0 -state normal
         $menu entryconfigure 1 -state normal
         $menu entryconfigure 3 -state normal
@@ -59,13 +69,13 @@ proc PopUpMenu {menu entry X Y} {
         $menu entryconfigure 1 -state disabled
         $menu entryconfigure 3 -state disabled
     }
-    if {[string length [$entry get]]==0} {
+    if {[string length [$entryPath get]]==0} {
         $menu entryconfigure 5 -state disabled
     } else {
         $menu entryconfigure 5 -state normal
     }
 
-    tk_popup $entry.menu $X $Y
+    tk_popup $entryPath.menu $X $Y
 
     return
 }
@@ -77,14 +87,16 @@ proc PopUpMenu {menu entry X Y} {
 #    entryPath: Path of the entry
 ###############################################################################
 proc Cut {entryPath} {
-    if {[$entryPath selection present]} {
+    set sel [$entryPath selection present]
+    if {$sel==1} {
         event generate $entryPath <<Cut>>
     }
     return
 }
 
 proc Copy {entryPath} {
-    if {[$entryPath selection present]} {
+    set sel [$entryPath selection present]
+    if {$sel==1} {
         event generate $entryPath <<Copy>>
     }
     return
@@ -96,7 +108,8 @@ proc Paste {entryPath} {
 }
 
 proc Clear {entryPath} {
-    if {[$entryPath selection present]} {
+    set sel [$entryPath selection present]
+    if {$sel==1} {
         event generate $entryPath <<Clear>>
     }
     return
@@ -147,7 +160,8 @@ proc RightClick {entryPath x y X Y} {
     variable sel1
     variable sel2
 
-    if {[$entryPath selection present]} {
+    set sel [$entryPath selection present]
+    if {$sel==1} {
         set selp 1
         set sel1 [$entryPath index sel.first]
         set sel2 [$entryPath index sel.last]
